@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <Config.h>
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -37,7 +38,7 @@
 #include <FS.h>
 #include <Timer.h>
 #include <JSON.h>
-#include <Config.h>
+#include <Lexer.h>
 #include <text.h>
 #include <util.h>
 #include <i18n.h>
@@ -94,13 +95,11 @@ std::string Config::_defaults =
   "recurrence.indicator=R                         # What to show as a task recurrence indicator\n"
   "recurrence.limit=1                             # Number of future recurring pending tasks\n"
   "undo.style=side                                # Undo style - can be 'side', or 'diff'\n"
-  "burndown.bias=0.666                            # Weighted mean bias toward recent data\n"
   "regex=yes                                      # Assume all search/filter strings are regexes\n"
   "xterm.title=no                                 # Sets xterm title for some commands\n"
   "expressions=infix                              # Prefer infix over postfix expressions\n"
-  "dom=on                                         # Support DOM access\n"
   "json.array=on                                  # Enclose JSON output in [ ]\n"
-  "json.depends.array=on                          # Encode dependencies as a JSON array\n"
+  "json.depends.array=off                         # Encode dependencies as a JSON array\n"
   "abbreviation.minimum=2                         # Shortest allowed abbreviation\n"
   "\n"
   "# Dates\n"
@@ -157,7 +156,6 @@ std::string Config::_defaults =
   "\n"
   "# Color controls.\n"
   "color=on                                       # Enable color\n"
-#if defined(LINUX) || defined(DARWIN)
   "\n"
   "rule.precedence.color=deleted,completed,active,keyword.,tag.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,uda.\n"
   "\n"
@@ -232,85 +230,6 @@ std::string Config::_defaults =
   "color.undo.after=color2\n"
   "color.undo.before=color1\n"
   "\n"
-#else
-  "\n"
-  "rule.precedence.color=deleted,completed,active,keyword.,tag.,project.,overdue,scheduled,due.today,due,blocked,blocking,recurring,tagged,uda.\n"
-  "\n"
-  "# General decoration\n"
-  "rule.color.merge=yes\n"
-  "color.label=\n"
-  "color.label.sort=\n"
-  "color.alternate=\n"
-  "color.header=yellow\n"
-  "color.footnote=yellow\n"
-  "color.warning=bold red\n"
-  "color.error=white on red\n"
-  "color.debug=blue\n"
-  "\n"
-  "# Task state\n"
-  "color.completed=\n"
-  "color.deleted=\n"
-  "color.active=black on bright green\n"
-  "color.recurring=magenta\n"
-  "color.scheduled=white on green\n"
-  "color.until=\n"
-  "color.blocked=black on white\n"
-  "color.blocking=black on bright white\n"
-  "\n"
-  "# Project\n"
-  "color.project.none=\n"
-  "\n"
-  "# Priority UDA\n"
-  "color.uda.priority.H=bold white\n"
-  "color.uda.priority.M=white\n"
-  "color.uda.priority.L=\n"
-  "\n"
-  "# Tags\n"
-  "color.tag.next=bold yellow\n"
-  "color.tag.none=\n"
-  "color.tagged=green\n"
-  "\n"
-  "# Due\n"
-  "color.due=red\n"
-  "color.due.today=red\n"
-  "color.overdue=bold red\n"
-  "\n"
-  "# UDA\n"
-  "#color.uda.X=\n"
-  "\n"
-  "# Report: burndown\n"
-  "color.burndown.done=on green\n"
-  "color.burndown.pending=on red\n"
-  "color.burndown.started=on yellow\n"
-  "\n"
-  "# Report: history\n"
-  "color.history.add=black on red\n"
-  "color.history.delete=black on yellow\n"
-  "color.history.done=black on green\n"
-  "\n"
-  "# Report: summary\n"
-  "color.summary.background=white on black\n"
-  "color.summary.bar=black on green\n"
-  "\n"
-  "# Command: calendar\n"
-  "color.calendar.due=white on red\n"
-  "color.calendar.due.today=bold white on red\n"
-  "color.calendar.holiday=black on bright yellow\n"
-  "color.calendar.overdue=black on bright red\n"
-  "color.calendar.today=bold white on bright blue\n"
-  "color.calendar.weekend=white on bright black\n"
-  "color.calendar.weeknumber=bold blue\n"
-  "\n"
-  "# Command: sync\n"
-  "color.sync.added=green\n"
-  "color.sync.changed=yellow\n"
-  "color.sync.rejected=red\n"
-  "\n"
-  "# Command: undo\n"
-  "color.undo.after=green\n"
-  "color.undo.before=red\n"
-  "\n"
-#endif
   "# UDA priority\n"
   "uda.priority.type=string                       # UDA priority is a string type\n"
   "uda.priority.label=Priority                    # UDA priority has a display label'\n"
@@ -340,7 +259,6 @@ std::string Config::_defaults =
   "sugar=yes                                      # Syntactic sugar\n"
   "obfuscate=no                                   # Obfuscate data for error reporting\n"
   "fontunderline=yes                              # Uses underlines rather than -------\n"
-  "shell.prompt=task>                             # Prompt used by the shell command\n"
   "\n"
   "# WARNING: Please read the documentation (man task-sync) before setting up\n"
   "#          Taskwarrior for Taskserver synchronization.\n"
@@ -435,7 +353,7 @@ std::string Config::_defaults =
   "\n"
   "report.next.description=Most urgent tasks\n"
   "report.next.labels=ID,Active,Age,Deps,P,Project,Tag,Recur,S,Due,Until,Description,Urg\n"
-  "report.next.columns=id,start.age,entry.age,depends,priority,project,tags,recur,scheduled.countdown,due.remaining,until.remaining,description,urgency\n"
+  "report.next.columns=id,start.age,entry.age,depends,priority,project,tags,recur,scheduled.countdown,due.relative,until.remaining,description,urgency\n"
   "report.next.filter=status:pending limit:page\n"
   "report.next.sort=urgency-\n"
   "\n"
@@ -459,7 +377,7 @@ std::string Config::_defaults =
   "\n"
   "report.blocking.description=Blocking tasks\n"
   "report.blocking.labels=ID,UUID,A,Deps,Project,Tags,R,W,Sch,Due,Until,Description,Urg\n"
-  "report.blocking.columns=id,uuid.short,start.active,depends,project,tags,recur,wait,scheduled.remaining,due.remaining,until.remaining,description.count,urgency\n"
+  "report.blocking.columns=id,uuid.short,start.active,depends,project,tags,recur,wait,scheduled.remaining,due.relative,until.remaining,description.count,urgency\n"
   "report.blocking.sort=urgency-,due+,entry+\n"
   "report.blocking.filter= status:pending +BLOCKING\n"
   "\n";
@@ -477,13 +395,6 @@ Config::Config ()
 {
 }
 
-////////////////////////////////////////////////////////////////////////////////
-Config::Config (const std::string& file)
-{
-  setDefaults ();
-  load (file);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Read the Configuration file and populate the *this map.  The file format is
 // simply lines with name=value pairs.  Whitespace between name, = and value is
@@ -531,7 +442,7 @@ void Config::parse (const std::string& input, int nest /* = 1 */)
     if (pound != std::string::npos)
       line = line.substr (0, pound);
 
-    line = trim (line, " \t"); // no i18n
+    line = Lexer::trim (line, " \t"); // no i18n
 
     // Skip empty lines.
     if (line.length () > 0)
@@ -539,8 +450,8 @@ void Config::parse (const std::string& input, int nest /* = 1 */)
       auto equal = line.find ("="); // no i18n
       if (equal != std::string::npos)
       {
-        std::string key   = trim (line.substr (0, equal), " \t"); // no i18n
-        std::string value = trim (line.substr (equal+1, line.length () - equal), " \t"); // no i18n
+        std::string key   = Lexer::trim (line.substr (0, equal), " \t"); // no i18n
+        std::string value = Lexer::trim (line.substr (equal+1, line.length () - equal), " \t"); // no i18n
 
         (*this)[key] = json::decode (value);
       }
@@ -549,7 +460,7 @@ void Config::parse (const std::string& input, int nest /* = 1 */)
         auto include = line.find ("include"); // no i18n.
         if (include != std::string::npos)
         {
-          Path included (trim (line.substr (include + 7), " \t"));
+          Path included (Lexer::trim (line.substr (include + 7), " \t"));
           if (included.is_absolute ())
           {
             if (included.readable ())
@@ -643,14 +554,19 @@ bool Config::has (const std::string& key)
 // Return the configuration value given the specified key.
 std::string Config::get (const std::string& key)
 {
-  return (*this)[key];
+  auto found = find (key);
+  if (found != end ())
+    return found->second;
+
+  return "";
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 int Config::getInteger (const std::string& key)
 {
-  if ((*this).find (key) != (*this).end ())
-    return strtoimax ((*this)[key].c_str (), NULL, 10);
+  auto found = find (key);
+  if (found != end ())
+    return strtoimax (found->second.c_str (), nullptr, 10);
 
   return 0;
 }
@@ -660,11 +576,12 @@ double Config::getReal (const std::string& key)
 {
   //NOTE: Backwards compatible handling of next coefficient.
   //TODO: Remove.
-  if (key == "urgency.user.tag.next.coefficient" and has("urgency.next.coefficient"))
-    return getReal("urgency.next.coefficient");
+  if (key == "urgency.user.tag.next.coefficient" and has ("urgency.next.coefficient"))
+    return getReal ("urgency.next.coefficient");
 
-  if ((*this).find (key) != (*this).end ())
-    return strtod ((*this)[key].c_str (), NULL);
+  auto found = find (key);
+  if (found != end ())
+    return strtod (found->second.c_str (), nullptr);
 
   return 0.0;
 }
@@ -672,9 +589,10 @@ double Config::getReal (const std::string& key)
 ////////////////////////////////////////////////////////////////////////////////
 bool Config::getBoolean (const std::string& key)
 {
-  if ((*this).find (key) != (*this).end ())
+  auto found = find (key);
+  if (found != end ())
   {
-    std::string value = lowerCase ((*this)[key]);
+    std::string value = Lexer::lowerCase ((*this)[key]);
     if (value == "t"      ||  // TODO Deprecate
         value == "true"   ||
         value == "1"      ||
