@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <Context.h>
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -33,7 +34,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <Context.h>
 #include <FS.h>
 #include <Eval.h>
 #include <Variant.h>
@@ -71,7 +71,6 @@ Context::Context ()
 , data_dir ("~/.task")
 , config ()
 , tdb2 ()
-, dom ()
 , determine_color_use (true)
 , use_color (true)
 , run_gc (true)
@@ -339,15 +338,15 @@ int Context::run ()
       << " sort:"   << timer_sort.total ()
       << " render:" << timer_render.total ()
       << " hooks:"  << timer_hooks.total ()
-      << " other:"  << timer_total.total ()   -
-                       (timer_init.total ()   +
-                        timer_load.total ()   +
-                        timer_gc.total ()     +
-                        timer_filter.total () +
-                        timer_commit.total () +
-                        timer_sort.total ()   +
-                        timer_render.total () +
-                        timer_hooks.total ())
+      << " other:"  << timer_total.total ()  -
+                       timer_init.total ()   -
+                       timer_load.total ()   -
+                       timer_gc.total ()     -
+                       timer_filter.total () -
+                       timer_commit.total () -
+                       timer_sort.total ()   -
+                       timer_render.total () -
+                       timer_hooks.total ()
       << " total:"  << timer_total.total ()
       << "\n";
     debug (s.str ());
@@ -683,7 +682,7 @@ void Context::staticInitialization ()
 void Context::createDefaultConfig ()
 {
   // Do we need to create a default rc?
-  if (! rc_file.exists ())
+  if (rc_file._data != "" && ! rc_file.exists ())
   {
     if (config.getBoolean ("confirmation") &&
         !confirm (format (STRING_CONTEXT_CREATE_RC, home_dir, rc_file._data)))
@@ -832,12 +831,3 @@ void Context::debug (const std::string& input)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-void Context::clearMessages ()
-{
-  headers.clear ();
-  footnotes.clear ();
-  errors.clear ();
-  debugMessages.clear ();
-}
-
-////////////////////////////////////////////////////////////////////////////////
