@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -33,7 +33,6 @@
 #include <Task.h>
 #include <TDB2.h>
 #include <Hooks.h>
-#include <DOM.h>
 #include <FS.h>
 #include <CLI2.h>
 #include <Timer.h>
@@ -65,7 +64,6 @@ public:
   void footnote (const std::string&);  // Footnote message sink
   void debug (const std::string&);     // Debug message sink
   void error (const std::string&);     // Error message sink - non-maskable
-  void clearMessages ();
 
   void decomposeSortField (const std::string&, std::string&, bool&, bool&);
 
@@ -86,7 +84,6 @@ public:
 
   TDB2                                tdb2;
   Hooks                               hooks;
-  DOM                                 dom;
 
   bool                                determine_color_use;
   bool                                use_color;
