@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -30,19 +30,8 @@
 #include <string>
 #include <Variant.h>
 #include <Task.h>
-#include <time.h>
 
-class DOM
-{
-public:
-  DOM ();
-  ~DOM ();
-
-  bool get (const std::string&, Variant&);
-  bool get (const std::string&, const Task&, Variant&);
-
-private:
-};
+bool getDOM (const std::string&, Variant&);
+bool getDOM (const std::string&, const Task&, Variant&);
 
 #endif
-////////////////////////////////////////////////////////////////////////////////
