@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2013 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,12 +25,12 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <Eval.h>
 #include <map>
 #include <time.h>
 #include <Context.h>
 #include <Task.h>
 #include <Color.h>
-#include <Eval.h>
 #include <text.h>
 #include <i18n.h>
 
@@ -104,16 +104,10 @@ static bool namedConstants (const std::string& name, Variant& value)
 
 ////////////////////////////////////////////////////////////////////////////////
 Eval::Eval ()
-: _debug (false)
 {
   addSource (namedConstants);
 }
 
-////////////////////////////////////////////////////////////////////////////////
-Eval::~Eval ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 void Eval::addSource (bool (*source)(const std::string&, Variant&))
 {
@@ -165,33 +159,6 @@ void Eval::evaluatePostfixExpression (const std::string& e, Variant& v) const
   evaluatePostfixStack (tokens, v);
 }
 
-////////////////////////////////////////////////////////////////////////////////
-void Eval::compileExpression (const std::string& e)
-{
-  // Reduce e to a vector of tokens.
-  Lexer l (e);
-  std::string token;
-  Lexer::Type type;
-  while (l.token (token, type))
-  {
-    if (_debug)
-      context.debug ("Lexer '" + token + "' " + Lexer::typeToString (type));
-    _compiled.push_back (std::pair <std::string, Lexer::Type> (token, type));
-  }
-
-  // Parse for syntax checking and operator replacement.
-  if (_debug)
-    context.debug ("[1;37;42mFILTER[0m Infix        " + dump (_compiled));
-  infixParse (_compiled);
-  if (_debug)
-    context.debug ("[1;37;42mFILTER[0m Infix parsed " + dump (_compiled));
-
-  // Convert infix --> postfix.
-  infixToPostfix (_compiled);
-  if (_debug)
-    context.debug ("[1;37;42mFILTER[0m Postfix      " + dump (_compiled));
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 void Eval::compileExpression (
   const std::vector <std::pair <std::string, Lexer::Type>>& precompiled)
@@ -257,8 +224,7 @@ void Eval::evaluatePostfixStack (
 
   // This is stack used by the postfix evaluator.
   std::vector <Variant> values;
-
-  for (auto& token : tokens)
+  for (const auto& token : tokens)
   {
     // Unary operators.
     if (token.second == Lexer::Type::op &&
@@ -893,4 +859,3 @@ std::string Eval::dump (
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-
