@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,12 +25,13 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <Filter.h>
 #include <algorithm>
 #include <Context.h>
+#include <DOM.h>
 #include <Eval.h>
 #include <Variant.h>
 #include <Dates.h>
-#include <Filter.h>
 #include <i18n.h>
 #include <text.h>
 #include <util.h>
@@ -45,7 +46,7 @@ Task& contextTask = dummy;
 ////////////////////////////////////////////////////////////////////////////////
 bool domSource (const std::string& identifier, Variant& value)
 {
-  if (context.dom.get (identifier, contextTask, value))
+  if (getDOM (identifier, contextTask, value))
   {
     value.source (identifier);
     return true;
@@ -54,19 +55,6 @@ bool domSource (const std::string& identifier, Variant& value)
   return false;
 }
 
-////////////////////////////////////////////////////////////////////////////////
-Filter::Filter ()
-: _startCount (0)
-, _endCount (0)
-, _safety (true)
-{
-}
-
-////////////////////////////////////////////////////////////////////////////////
-Filter::~Filter ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Take an input set of tasks and filter into a subset.
 void Filter::subset (const std::vector <Task>& input, std::vector <Task>& output)
@@ -199,40 +187,20 @@ void Filter::subset (std::vector <Task>& output)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-bool Filter::hasFilter ()
+bool Filter::hasFilter () const
 {
-  for (auto& a : context.cli2._args)
+  for (const auto& a : context.cli2._args)
     if (a.hasTag ("FILTER"))
       return true;
 
   return false;
 }
 
-////////////////////////////////////////////////////////////////////////////////
-bool Filter::hasModifications ()
-{
-  for (auto& a : context.cli2._args)
-    if (a.hasTag ("MODIFICATION"))
-      return true;
-
-  return false;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-bool Filter::hasMiscellaneous ()
-{
-  for (auto& a : context.cli2._args)
-    if (a.hasTag ("MISCELLANEOUS"))
-      return true;
-
-  return false;
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // If the filter contains no 'or', 'xor' or 'not' operators, and only includes
 // status values 'pending', 'waiting' or 'recurring', then the filter is
 // guaranteed to only need data from pending.data.
-bool Filter::pendingOnly ()
+bool Filter::pendingOnly () const
 {
   // When GC is off, there are no shortcuts.
   if (! context.config.getBoolean ("gc"))
@@ -254,7 +222,7 @@ bool Filter::pendingOnly ()
   int countXor       = 0;
   int countNot       = 0;
 
-  for (auto& a : context.cli2._args)
+  for (const auto& a : context.cli2._args)
   {
     if (a.hasTag ("FILTER"))
     {
@@ -294,31 +262,35 @@ bool Filter::pendingOnly ()
 ////////////////////////////////////////////////////////////////////////////////
 // Disaster avoidance mechanism. If a !READONLY has no filter, then it can cause
 // all tasks to be modified. This is usually not intended.
-void Filter::safety ()
+void Filter::safety () const
 {
   if (_safety)
   {
-    for (auto& a : context.cli2._args)
+    bool readonly = true;
+    bool filter = false;
+    for (const auto& a : context.cli2._args)
     {
-      if (a.hasTag ("CMD"))
-      {
-        if (! a.hasTag ("READONLY"))
-        {
-          if (! context.config.getBoolean ("allow.empty.filter"))
-            throw std::string (STRING_TASK_SAFETY_ALLOW);
+      if (a.hasTag ("CMD") &&
+          ! a.hasTag ("READONLY"))
+        readonly = false;
 
-          // If user is willing to be asked, this can be avoided.
-          if (context.config.getBoolean ("confirmation") &&
-              confirm (STRING_TASK_SAFETY_VALVE))
-            return;
+      if (a.hasTag ("FILTER"))
+        filter = true;
+    }
 
-          // Sounds the alarm.
-          throw std::string (STRING_TASK_SAFETY_FAIL);
-        }
+    if (! readonly &&
+        ! filter)
+    {
+      if (! context.config.getBoolean ("allow.empty.filter"))
+         throw std::string (STRING_TASK_SAFETY_ALLOW);
 
-        // CMD was found.
+      // If user is willing to be asked, this can be avoided.
+      if (context.config.getBoolean ("confirmation") &&
+          confirm (STRING_TASK_SAFETY_VALVE))
         return;
-      }
+
+      // Sound the alarm.
+      throw std::string (STRING_TASK_SAFETY_FAIL);
     }
   }
 }
