@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <Hooks.h>
 #include <algorithm>
 // If <iostream> is included, put it after <stdio.h>, because it includes
 // <stdio.h>, and therefore would ignore the _WITH_GETLINE.
@@ -36,8 +37,9 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <Context.h>
+#include <Variant.h>
+#include <DOM.h>
 #include <JSON.h>
-#include <Hooks.h>
 #include <Timer.h>
 #include <text.h>
 #include <util.h>
@@ -45,18 +47,6 @@
 
 extern Context context;
 
-////////////////////////////////////////////////////////////////////////////////
-Hooks::Hooks ()
-: _enabled (true)
-, _debug (0)
-{
-}
-
-////////////////////////////////////////////////////////////////////////////////
-Hooks::~Hooks ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 void Hooks::initialize ()
 {
@@ -76,14 +66,17 @@ void Hooks::initialize ()
       for (auto& i : _scripts)
       {
         Path p (i);
-        std::string name = p.name ();
-        if (name.substr (0, 6) == "on-add"    ||
-            name.substr (0, 9) == "on-modify" ||
-            name.substr (0, 9) == "on-launch" ||
-            name.substr (0, 7) == "on-exit")
-          context.debug ("Found hook script " + i);
-        else
-          context.debug ("Found misnamed hook script " + i);
+        if (! p.is_directory ())
+        {
+          std::string name = p.name ();
+          if (name.substr (0, 6) == "on-add"    ||
+              name.substr (0, 9) == "on-modify" ||
+              name.substr (0, 9) == "on-launch" ||
+              name.substr (0, 7) == "on-exit")
+            context.debug ("Found hook script " + i);
+          else
+            context.debug ("Found misnamed hook script " + i);
+        }
       }
     }
   }
@@ -113,7 +106,7 @@ bool Hooks::enable (bool value)
 // - all emitted non-JSON lines are considered feedback or error messages
 //   depending on the status code.
 //
-void Hooks::onLaunch ()
+void Hooks::onLaunch () const
 {
   if (! _enabled)
     return;
@@ -166,7 +159,7 @@ void Hooks::onLaunch ()
 // - all emitted non-JSON lines are considered feedback or error messages
 //   depending on the status code.
 //
-void Hooks::onExit ()
+void Hooks::onExit () const
 {
   if (! _enabled)
     return;
@@ -228,7 +221,7 @@ void Hooks::onExit ()
 // - all emitted non-JSON lines are considered feedback or error messages
 //   depending on the status code.
 //
-void Hooks::onAdd (Task& task)
+void Hooks::onAdd (Task& task) const
 {
   if (! _enabled)
     return;
@@ -294,7 +287,7 @@ void Hooks::onAdd (Task& task)
 // - all emitted non-JSON lines are considered feedback or error messages
 //   depending on the status code.
 //
-void Hooks::onModify (const Task& before, Task& after)
+void Hooks::onModify (const Task& before, Task& after) const
 {
   if (! _enabled)
     return;
@@ -348,16 +341,16 @@ void Hooks::onModify (const Task& before, Task& after)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::vector <std::string> Hooks::list ()
+std::vector <std::string> Hooks::list () const
 {
   return _scripts;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::vector <std::string> Hooks::scripts (const std::string& event)
+std::vector <std::string> Hooks::scripts (const std::string& event) const
 {
   std::vector <std::string> matching;
-  for (auto& i : _scripts)
+  for (const auto& i : _scripts)
   {
     if (i.find ("/" + event) != std::string::npos)
     {
@@ -502,7 +495,7 @@ void Hooks::assertFeedback (const std::vector <std::string>& input) const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::vector <std::string>& Hooks::buildHookScriptArgs (std::vector <std::string>& args)
+std::vector <std::string>& Hooks::buildHookScriptArgs (std::vector <std::string>& args) const
 {
   Variant v;
 
@@ -510,7 +503,7 @@ std::vector <std::string>& Hooks::buildHookScriptArgs (std::vector <std::string>
   args.push_back ("api:2");
 
   // Command line Taskwarrior was called with.
-  context.dom.get ("context.args", v);
+  getDOM ("context.args", v);
   args.push_back ("args:" + std::string (v));
 
   // Command to be executed.
@@ -532,7 +525,7 @@ std::vector <std::string>& Hooks::buildHookScriptArgs (std::vector <std::string>
 int Hooks::callHookScript (
   const std::string& script,
   const std::vector <std::string>& input,
-  std::vector <std::string>& output)
+  std::vector <std::string>& output) const
 {
   if (_debug >= 1)
     context.debug ("Hook: Calling " + script);
@@ -540,12 +533,12 @@ int Hooks::callHookScript (
   if (_debug >= 2)
   {
     context.debug ("Hook: input");
-    for (auto& i : input)
+    for (const auto& i : input)
       context.debug ("  " + i);
   }
 
   std::string inputStr;
-  for (auto& i : input)
+  for (const auto& i : input)
     inputStr += i + "\n";
 
   std::vector <std::string> args;
@@ -553,7 +546,7 @@ int Hooks::callHookScript (
   if (_debug >= 2)
   {
     context.debug ("Hooks: args");
-    for (auto& arg: args)
+    for (const auto& arg: args)
       context.debug ("  " + arg);
   }
 
@@ -575,7 +568,7 @@ int Hooks::callHookScript (
   if (_debug >= 2)
   {
     context.debug ("Hook: output");
-    for (auto& i : output)
+    for (const auto& i : output)
       if (i != "")
         context.debug ("  " + i);
 
