@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,14 +25,16 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <ISO8601.h>
 #include <sstream>
 #include <iomanip>
 #include <stdlib.h>
 #include <assert.h>
 #include <Lexer.h>
 #include <util.h>
-#include <ISO8601.h>
+#ifdef PRODUCT_TASKWARRIOR
 #include <Dates.h>
+#endif
 #include <text.h>
 #include <utf8.h>
 #include <i18n.h>
@@ -178,12 +180,6 @@ ISO8601d::~ISO8601d ()
 {
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ISO8601d::operator time_t () const
-{
-  return _date;
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Supported:
 //
@@ -236,7 +232,16 @@ bool ISO8601d::parse (
 {
   auto i = start;
   Nibbler n (input.substr (i));
-  if (parse_formatted (n, format))
+
+  // Parse epoch first, as it's the most common scenario.
+  if (parse_epoch (n))
+  {
+    // ::validate and ::resolve are not needed in this case.
+    start = n.cursor ();
+    return true;
+  }
+
+  else if (parse_formatted (n, format))
   {
     // Check the values and determine time_t.
     if (validate ())
@@ -253,9 +258,7 @@ bool ISO8601d::parse (
   else if (parse_date_time     (n)   || // Strictest first.
            parse_date_time_ext (n)   ||
            (ISO8601d::isoEnabled &&
-            (parse_date_time     (n) ||
-             parse_date_time_ext (n) ||
-             parse_date_ext      (n) ||
+            (parse_date_ext      (n) ||
              parse_time_utc_ext  (n) ||
              parse_time_off_ext  (n) ||
              parse_time_ext      (n)))) // Time last, as it is the most permissive.
@@ -269,8 +272,7 @@ bool ISO8601d::parse (
     }
   }
 
-  else if (parse_epoch (n) ||
-           parse_named (n))
+  else if (parse_named (n))
   {
     // ::validate and ::resolve are not needed in this case.
     start = n.cursor ();
@@ -520,7 +522,7 @@ bool ISO8601d::parse_formatted (Nibbler& n, const std::string& format)
         std::string dayName;
         if (n.getUntil (format[f + 1], dayName))
         {
-          wday = ISO8601d::dayOfWeek (lowerCase (dayName));
+          wday = ISO8601d::dayOfWeek (Lexer::lowerCase (dayName));
           if (wday == -1)
           {
             n.restore ();
@@ -549,7 +551,7 @@ bool ISO8601d::parse_formatted (Nibbler& n, const std::string& format)
         std::string monthName;
         if (n.getUntil (format[f + 1], monthName))
         {
-          month = ISO8601d::monthOfYear (lowerCase (monthName));
+          month = ISO8601d::monthOfYear (Lexer::lowerCase (monthName));
           if (month == -1)
           {
             n.restore ();
@@ -620,6 +622,7 @@ bool ISO8601d::parse_formatted (Nibbler& n, const std::string& format)
 ////////////////////////////////////////////////////////////////////////////////
 bool ISO8601d::parse_named (Nibbler& n)
 {
+#ifdef PRODUCT_TASKWARRIOR
   n.save ();
   std::string token;
   if (n.getUntilWS (token))
@@ -633,6 +636,8 @@ bool ISO8601d::parse_named (Nibbler& n)
   }
 
   n.restore ();
+#endif
+
   return false;
 }
 
@@ -1049,6 +1054,28 @@ std::string ISO8601d::toISO () const
   return iso.str ();
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// 1998-01-19T07:00:00 =  YYYY-MM-DDThh:mm:ss
+std::string ISO8601d::toISOLocalExtended () const
+{
+  struct tm* t = localtime (&_date);
+
+  std::stringstream iso;
+  iso << std::setw (4) << std::setfill ('0') << t->tm_year + 1900
+      << "-"
+      << std::setw (2) << std::setfill ('0') << t->tm_mon + 1
+      << "-"
+      << std::setw (2) << std::setfill ('0') << t->tm_mday
+      << "T"
+      << std::setw (2) << std::setfill ('0') << t->tm_hour
+      << ":"
+      << std::setw (2) << std::setfill ('0') << t->tm_min
+      << ":"
+      << std::setw (2) << std::setfill ('0') << t->tm_sec;
+
+  return iso.str ();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 double ISO8601d::toJulian () const
 {
@@ -1069,44 +1096,37 @@ void ISO8601d::toMDY (int& m, int& d, int& y) const
 const std::string ISO8601d::toString (
   const std::string& format /*= "m/d/Y" */) const
 {
-  // Making this local copy seems to fix a bug.  Remove the local copy and
-  // you'll see segmentation faults and all kinds of gibberish.
-  std::string localFormat = format;
-
-  char buffer[12];
-  std::string formatted;
-  for (unsigned int i = 0; i < localFormat.length (); ++i)
+  std::stringstream formatted;
+  for (unsigned int i = 0; i < format.length (); ++i)
   {
-    int c = localFormat[i];
+    int c = format[i];
     switch (c)
     {
-    case 'm': sprintf (buffer, "%d",    this->month ());                        break;
-    case 'M': sprintf (buffer, "%02d",  this->month ());                        break;
-    case 'd': sprintf (buffer, "%d",    this->day ());                          break;
-    case 'D': sprintf (buffer, "%02d",  this->day ());                          break;
-    case 'y': sprintf (buffer, "%02d",  this->year () % 100);                   break;
-    case 'Y': sprintf (buffer, "%d",    this->year ());                         break;
-    case 'a': sprintf (buffer, "%.3s",  ISO8601d::dayName (dayOfWeek ()).c_str ()); break;
-    case 'A': sprintf (buffer, "%.10s", ISO8601d::dayName (dayOfWeek ()).c_str ()); break;
-    case 'b': sprintf (buffer, "%.3s",  ISO8601d::monthName (month ()).c_str ());   break;
-    case 'B': sprintf (buffer, "%.10s", ISO8601d::monthName (month ()).c_str ());   break;
-    case 'v': sprintf (buffer, "%d",    ISO8601d::weekOfYear (ISO8601d::dayOfWeek (ISO8601d::weekstart))); break;
-    case 'V': sprintf (buffer, "%02d",  ISO8601d::weekOfYear (ISO8601d::dayOfWeek (ISO8601d::weekstart))); break;
-    case 'h': sprintf (buffer, "%d",    this->hour ());                         break;
-    case 'H': sprintf (buffer, "%02d",  this->hour ());                         break;
-    case 'n': sprintf (buffer, "%d",    this->minute ());                       break;
-    case 'N': sprintf (buffer, "%02d",  this->minute ());                       break;
-    case 's': sprintf (buffer, "%d",    this->second ());                       break;
-    case 'S': sprintf (buffer, "%02d",  this->second ());                       break;
-    case 'j': sprintf (buffer, "%d",    this->dayOfYear ());                    break;
-    case 'J': sprintf (buffer, "%03d",  this->dayOfYear ());                    break;
-    default:  sprintf (buffer, "%c",    c);                                     break;
+    case 'm': formatted                                        << this->month ();         break;
+    case 'M': formatted << std::setw (2) << std::setfill ('0') << this->month ();         break;
+    case 'd': formatted                                        << this->day ();           break;
+    case 'D': formatted << std::setw (2) << std::setfill ('0') << this->day ();           break;
+    case 'y': formatted << std::setw (2) << std::setfill ('0') << (this->year () % 100);  break;
+    case 'Y': formatted                                        << this->year ();          break;
+    case 'a': formatted                                        << ISO8601d::dayNameShort (dayOfWeek ()); break;
+    case 'A': formatted                                        << ISO8601d::dayName (dayOfWeek ());      break;
+    case 'b': formatted                                        << ISO8601d::monthNameShort (month ());   break;
+    case 'B': formatted                                        << ISO8601d::monthName (month ());        break;
+    case 'v': formatted                                        << ISO8601d::weekOfYear (ISO8601d::dayOfWeek (ISO8601d::weekstart)); break;
+    case 'V': formatted << std::setw (2) << std::setfill ('0') << ISO8601d::weekOfYear (ISO8601d::dayOfWeek (ISO8601d::weekstart)); break;
+    case 'h': formatted                                        << this->hour ();          break;
+    case 'H': formatted << std::setw (2) << std::setfill ('0') << this->hour ();          break;
+    case 'n': formatted                                        << this->minute ();        break;
+    case 'N': formatted << std::setw (2) << std::setfill ('0') << this->minute ();        break;
+    case 's': formatted                                        << this->second ();        break;
+    case 'S': formatted << std::setw (2) << std::setfill ('0') << this->second ();        break;
+    case 'j': formatted                                        << this->dayOfYear ();     break;
+    case 'J': formatted << std::setw (3) << std::setfill ('0') << this->dayOfYear ();     break;
+    default:  formatted                                        << static_cast <char> (c); break;
     }
-
-    formatted += buffer;
   }
 
-  return formatted;
+  return formatted.str ();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1249,25 +1269,32 @@ std::string ISO8601d::monthName (int month)
 
   assert (month > 0);
   assert (month <= 12);
-  return ucFirst (months[month - 1]);
+  return Lexer::ucFirst (months[month - 1]);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // Static
-void ISO8601d::dayName (int dow, std::string& name)
+std::string ISO8601d::monthNameShort (int month)
 {
-  static const char* days[7] =
+  static const char* months[12] =
   {
-    STRING_DATE_SUNDAY,
-    STRING_DATE_MONDAY,
-    STRING_DATE_TUESDAY,
-    STRING_DATE_WEDNESDAY,
-    STRING_DATE_THURSDAY,
-    STRING_DATE_FRIDAY,
-    STRING_DATE_SATURDAY,
+    STRING_DATE_JANUARY,
+    STRING_DATE_FEBRUARY,
+    STRING_DATE_MARCH,
+    STRING_DATE_APRIL,
+    STRING_DATE_MAY,
+    STRING_DATE_JUNE,
+    STRING_DATE_JULY,
+    STRING_DATE_AUGUST,
+    STRING_DATE_SEPTEMBER,
+    STRING_DATE_OCTOBER,
+    STRING_DATE_NOVEMBER,
+    STRING_DATE_DECEMBER,
   };
 
-  name = ucFirst (days[dow]);
+  assert (month > 0);
+  assert (month <= 12);
+  return Lexer::ucFirst (months[month - 1]).substr (0, 3);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1285,7 +1312,25 @@ std::string ISO8601d::dayName (int dow)
     STRING_DATE_SATURDAY,
   };
 
-  return ucFirst (days[dow]);
+  return Lexer::ucFirst (days[dow]);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// Static
+std::string ISO8601d::dayNameShort (int dow)
+{
+  static const char* days[7] =
+  {
+    STRING_DATE_SUNDAY,
+    STRING_DATE_MONDAY,
+    STRING_DATE_TUESDAY,
+    STRING_DATE_WEDNESDAY,
+    STRING_DATE_THURSDAY,
+    STRING_DATE_FRIDAY,
+    STRING_DATE_SATURDAY,
+  };
+
+  return Lexer::ucFirst (days[dow]).substr (0, 3);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1534,12 +1579,6 @@ bool ISO8601d::sameYear (const ISO8601d& rhs) const
   return this->year () == rhs.year ();
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ISO8601d ISO8601d::operator+ (time_t delta)
-{
-  return ISO8601d (_date + delta);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 ISO8601d ISO8601d::operator+ (const int delta)
 {
@@ -1629,6 +1668,7 @@ void ISO8601d::operator++ (int)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+/*
 std::string ISO8601d::dump () const
 {
   std::stringstream s;
@@ -1647,6 +1687,7 @@ std::string ISO8601d::dump () const
 
   return s.str ();
 }
+*/
 
 ////////////////////////////////////////////////////////////////////////////////
 ISO8601p::ISO8601p ()
@@ -1902,21 +1943,30 @@ const std::string ISO8601p::format () const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+// Range      Representation
+// ---------  ---------------------
+// >= 365d    {n.n}y
+// >= 90d     {n}mo
+// >= 14d     {n}w
+// >= 1d      {n}d
+// >= 1h      {n}h
+// >= 1min    {n}min
+//            {n}s
+//
 const std::string ISO8601p::formatVague () const
 {
-  char formatted[24];
   float days = (float) _period / 86400.0;
 
-       if (_period >= 86400 * 365) sprintf (formatted, "%.1fy", (days / 365.0));
-  else if (_period >= 86400 * 84)  sprintf (formatted, "%1dmo", (int) (days / 30));
-  else if (_period >= 86400 * 13)  sprintf (formatted, "%dw",   (int) (float) (days / 7.0));
-  else if (_period >= 86400)       sprintf (formatted, "%dd",   (int) days);
-  else if (_period >= 3600)        sprintf (formatted, "%dh",   (int) (_period / 3600));
-  else if (_period >= 60)          sprintf (formatted, "%dmin", (int) (_period / 60));
-  else if (_period >= 1)           sprintf (formatted, "%ds",   (int) _period);
-  else                            formatted[0] = '\0';
+  std::stringstream formatted;
+       if (_period >= 86400 * 365) formatted << std::fixed << std::setprecision (1) << (days / 365) << "y";
+  else if (_period >= 86400 * 90)  formatted << static_cast <int> (days / 30)       << "mo";
+  else if (_period >= 86400 * 14)  formatted << static_cast <int> (days / 7)        << "w";
+  else if (_period >= 86400)       formatted << static_cast <int> (days)            << "d";
+  else if (_period >= 3600)        formatted << static_cast <int> (_period / 3600)  << "h";
+  else if (_period >= 60)          formatted << static_cast <int> (_period / 60)    << "min";
+  else if (_period >= 1)           formatted << static_cast <int> (_period)         << "s";
 
-  return std::string (formatted);
+  return formatted.str ();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1998,6 +2048,7 @@ void ISO8601p::resolve ()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+/*
 std::string ISO8601p::dump () const
 {
   std::stringstream s;
@@ -2013,5 +2064,6 @@ std::string ISO8601p::dump () const
 
   return s.str ();
 }
+*/
 
 ////////////////////////////////////////////////////////////////////////////////
