@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,10 +25,45 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <JSON.h>
 #include <text.h>
 #include <i18n.h>
 #include <utf8.h>
-#include <JSON.h>
+
+const char *json_encode[] = {
+  "\x00", "\x01", "\x02", "\x03", "\x04", "\x05", "\x06", "\x07",
+   "\\b",  "\\t",  "\\n", "\x0b",  "\\f",  "\\r", "\x0e", "\x0f",
+  "\x10", "\x11", "\x12", "\x13", "\x14", "\x15", "\x16", "\x17",
+  "\x18", "\x19", "\x1a", "\x1b", "\x1c", "\x1d", "\x1e", "\x1f",
+  "\x20", "\x21", "\\\"", "\x23", "\x24", "\x25", "\x26", "\x27",
+  "\x28", "\x29", "\x2a", "\x2b", "\x2c", "\x2d", "\x2e",  "\\/",
+  "\x30", "\x31", "\x32", "\x33", "\x34", "\x35", "\x36", "\x37",
+  "\x38", "\x39", "\x3a", "\x3b", "\x3c", "\x3d", "\x3e", "\x3f",
+  "\x40", "\x41", "\x42", "\x43", "\x44", "\x45", "\x46", "\x47",
+  "\x48", "\x49", "\x4a", "\x4b", "\x4c", "\x4d", "\x4e", "\x4f",
+  "\x50", "\x51", "\x52", "\x53", "\x54", "\x55", "\x56", "\x57",
+  "\x58", "\x59", "\x5a", "\x5b", "\\\\", "\x5d", "\x5e", "\x5f",
+  "\x60", "\x61", "\x62", "\x63", "\x64", "\x65", "\x66", "\x67",
+  "\x68", "\x69", "\x6a", "\x6b", "\x6c", "\x6d", "\x6e", "\x6f",
+  "\x70", "\x71", "\x72", "\x73", "\x74", "\x75", "\x76", "\x77",
+  "\x78", "\x79", "\x7a", "\x7b", "\x7c", "\x7d", "\x7e", "\x7f",
+  "\x80", "\x81", "\x82", "\x83", "\x84", "\x85", "\x86", "\x87",
+  "\x88", "\x89", "\x8a", "\x8b", "\x8c", "\x8d", "\x8e", "\x8f",
+  "\x90", "\x91", "\x92", "\x93", "\x94", "\x95", "\x96", "\x97",
+  "\x98", "\x99", "\x9a", "\x9b", "\x9c", "\x9d", "\x9e", "\x9f",
+  "\xa0", "\xa1", "\xa2", "\xa3", "\xa4", "\xa5", "\xa6", "\xa7",
+  "\xa8", "\xa9", "\xaa", "\xab", "\xac", "\xad", "\xae", "\xaf",
+  "\xb0", "\xb1", "\xb2", "\xb3", "\xb4", "\xb5", "\xb6", "\xb7",
+  "\xb8", "\xb9", "\xba", "\xbb", "\xbc", "\xbd", "\xbe", "\xbf",
+  "\xc0", "\xc1", "\xc2", "\xc3", "\xc4", "\xc5", "\xc6", "\xc7",
+  "\xc8", "\xc9", "\xca", "\xcb", "\xcc", "\xcd", "\xce", "\xcf",
+  "\xd0", "\xd1", "\xd2", "\xd3", "\xd4", "\xd5", "\xd6", "\xd7",
+  "\xd8", "\xd9", "\xda", "\xdb", "\xdc", "\xdd", "\xde", "\xdf",
+  "\xe0", "\xe1", "\xe2", "\xe3", "\xe4", "\xe5", "\xe6", "\xe7",
+  "\xe8", "\xe9", "\xea", "\xeb", "\xec", "\xed", "\xee", "\xef",
+  "\xf0", "\xf1", "\xf2", "\xf3", "\xf4", "\xf5", "\xf6", "\xf7",
+  "\xf8", "\xf9", "\xfa", "\xfb", "\xfc", "\xfd", "\xfe", "\xff"
+};
 
 ////////////////////////////////////////////////////////////////////////////////
 json::value* json::value::parse (Nibbler& nibbler)
@@ -66,7 +101,7 @@ json::string::string (const std::string& other)
 json::string* json::string::parse (Nibbler& nibbler)
 {
   std::string value;
-  if (nibbler.getQuoted ('"', value, false))
+  if (nibbler.getQuoted ('"', value))
   {
     json::string* s = new json::string ();
     s->_data = value;
@@ -303,7 +338,7 @@ bool json::object::parse_pair (
 {
   Nibbler n (nibbler);
 
-  if (n.getQuoted ('"', name, false))
+  if (n.getQuoted ('"', name))
   {
     n.skipWS ();
     if (n.skip (':'))
@@ -377,66 +412,80 @@ json::value* json::parse (const std::string& input)
 std::string json::encode (const std::string& input)
 {
   std::string output;
+  output.reserve ((input.size () * 6) / 5);  // 20% increase.
 
-  for (auto& i : input)
+  auto last = input.begin ();
+  for (auto i = input.begin (); i != input.end (); ++i)
   {
-    switch (i)
+    switch (*i)
     {
     // Simple translations.
-    case '"':  output += "\\\"";   break;
-    case '\\': output += "\\\\";   break;
-    case '/':  output += "\\/";    break;
-    case '\b': output += "\\b";    break;
-    case '\f': output += "\\f";    break;
-    case '\n': output += "\\n";    break;
-    case '\r': output += "\\r";    break;
-    case '\t': output += "\\t";    break;
+    case  '"':
+    case '\\':
+    case  '/':
+    case '\b':
+    case '\f':
+    case '\n':
+    case '\r':
+    case '\t':
+      output.append (last, i);
+      output += json_encode[(unsigned char)(*i)];
+      last = i + 1;
 
     // Default NOP.
-    default:   output += i; break;
     }
   }
 
+  output.append (last, input.end ());
+
   return output;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// TODO Using a state machine would speed this up.
 std::string json::decode (const std::string& input)
 {
   std::string output;
-  for (unsigned int i = 0; i < input.length (); ++i)
+  output.reserve (input.size ());  // Same size.
+
+  size_t pos = 0;
+
+  while (pos < input.length ())
   {
-    if (input[i] == '\\')
+    if (input[pos] == '\\')
     {
-      ++i;
-      switch (input[i])
+      ++pos;
+      switch (input[pos])
       {
-      // Simple translations.
-      case '"':  output += '"';  break;
-      case '\\': output += '\\'; break;
-      case '/':  output += '/';  break;
-      case 'b':  output += '\b'; break;
-      case 'f':  output += '\f'; break;
-      case 'n':  output += '\n'; break;
-      case 'r':  output += '\r'; break;
-      case 't':  output += '\t'; break;
+        // Simple translations.
+        case '"':  output += '"';  break;
+        case '\\': output += '\\'; break;
+        case '/':  output += '/';  break;
+        case 'b':  output += '\b'; break;
+        case 'f':  output += '\f'; break;
+        case 'n':  output += '\n'; break;
+        case 'r':  output += '\r'; break;
+        case 't':  output += '\t'; break;
 
-      // Compose a UTF8 unicode character.
-      case 'u':
-        output += utf8_character (utf8_codepoint (input.substr (++i)));
-        i += 3;
-        break;
+        // Compose a UTF8 unicode character.
+        case 'u':
+          output += utf8_character (utf8_codepoint (input.substr (++pos)));
+          pos += 3;
+          break;
 
-      // If it is an unrecognized sequence, do nothing.
-      default:
-        output += '\\';
-        output += input[i];
-        break;
+        // If it is an unrecognized sequence, do nothing.
+        default:
+          output += '\\';
+          output += input[pos];
+          break;
       }
+      ++pos;
     }
     else
-      output += input[i];
+    {
+      size_t next_backslash = input.find ('\\', pos);
+      output.append (input, pos, next_backslash - pos);
+      pos = next_backslash;
+    }
   }
 
   return output;
