@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,15 +25,12 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <stdlib.h>
-#include <string.h>
 #include <RX.h>
+#include <cstdlib>
+#include <cstring>
 
 ////////////////////////////////////////////////////////////////////////////////
 RX::RX ()
-: _compiled (false)
-, _pattern ("")
-, _case_sensitive (false)
 {
 }
 
@@ -51,8 +48,8 @@ RX::RX (
 ////////////////////////////////////////////////////////////////////////////////
 RX::RX (const RX& other)
 {
-  _compiled = false;
-  _pattern = other._pattern;
+  _compiled       = false;
+  _pattern        = other._pattern;
   _case_sensitive = other._case_sensitive;
 }
 
@@ -66,12 +63,9 @@ RX::~RX ()
 ////////////////////////////////////////////////////////////////////////////////
 RX& RX::operator= (const RX& other)
 {
-  if (this != &other)
-  {
-    _compiled = false;
-    _pattern = other._pattern;
-    _case_sensitive = other._case_sensitive;
-  }
+  _compiled       = false;
+  _pattern        = other._pattern;
+  _case_sensitive = other._case_sensitive;
 
   return *this;
 }
@@ -85,7 +79,7 @@ void RX::compile ()
 
     int result;
     if ((result = regcomp (&_regex, _pattern.c_str (),
-#ifdef DARWIN
+#if defined REG_ENHANCED
                            REG_ENHANCED | REG_EXTENDED | REG_NEWLINE |
 #else
                            REG_EXTENDED | REG_NEWLINE |
@@ -107,7 +101,7 @@ bool RX::match (const std::string& in)
   if (! _compiled)
     compile ();
 
-  return regexec (&_regex, in.c_str (), 0, NULL, 0) == 0 ? true : false;
+  return regexec (&_regex, in.c_str (), 0, nullptr, 0) == 0 ? true : false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
