@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -48,9 +48,9 @@ private:
   void compile ();
 
 private:
-  bool _compiled;
-  std::string _pattern;
-  bool _case_sensitive;
+  bool _compiled       {false};
+  std::string _pattern {};
+  bool _case_sensitive {false};
   regex_t _regex;
 };
 
