@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -59,7 +59,9 @@ public:
   void clear_lines ();
   void commit ();
 
-  void load_tasks ();
+  Task load_task (const std::string&);
+  void load_gc (Task&);
+  void load_tasks (bool from_gc = false);
   void load_lines ();
 
   // ID <--> UUID mapping.
@@ -71,10 +73,8 @@ public:
   void clear ();
   const std::string dump ();
 
-private:
   void dependency_scan ();
 
-public:
   bool _read_only;
   bool _dirty;
   bool _loaded_tasks;
@@ -95,8 +95,8 @@ public:
   File _file;
 
 private:
-  std::map <int, std::string> _I2U; // ID -> UUID map
-  std::map <std::string, int> _U2I; // UUID -> ID map
+  std::unordered_map <int, std::string> _I2U; // ID -> UUID map
+  std::unordered_map <std::string, int> _U2I; // UUID -> ID map
 };
 
 // TDB2 Class represents all the files in the task database.
@@ -106,7 +106,6 @@ public:
   static bool debug_mode;
 
   TDB2 ();
-  ~TDB2 ();
 
   void set_location (const std::string&);
   void add (Task&, bool add_to_backlog = true);
@@ -114,7 +113,7 @@ public:
   void commit ();
   void get_changes (std::vector <Task>&);
   void revert ();
-  int  gc ();
+  void gc ();
   int  next_id ();
   int  latest_id ();
 
