@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -34,7 +34,7 @@
 #include <time.h>
 #include <JSON.h>
 
-class Task : public std::map <std::string, std::string>
+class Task
 {
 public:
   static std::string defaultProject;
@@ -57,13 +57,10 @@ public:
   static float urgencyAgeMax;
 
 public:
-  Task ();                       // Default constructor
-  Task (const Task&);            // Copy constructor
-  Task& operator= (const Task&); // Assignment operator
-  bool operator== (const Task&); // Comparison operator
-  Task (const std::string&);     // Parse
-  Task (const json::object*);    // Parse
-  ~Task ();                      // Destructor
+  Task () = default;
+  bool operator== (const Task&);
+  Task (const std::string&);
+  Task (const json::object*);
 
   void parse (const std::string&);
   std::string composeF4 () const;
@@ -76,14 +73,13 @@ public:
   enum dateState {dateNotDue, dateAfterToday, dateLaterToday, dateEarlierToday, dateBeforeToday};
 
   // Public data.
-  int id;
-  float urgency_value;
-  bool recalc_urgency;
-
-  bool is_blocked;
-  bool is_blocking;
-
-  int annotation_count;
+  std::map <std::string, std::string> data {};
+  int id                                   {0};
+  float urgency_value                      {0.0};
+  bool recalc_urgency                      {true};
+  bool is_blocked                          {false};
+  bool is_blocking                         {false};
+  int annotation_count                     {0};
 
   // Series of helper functions.
   static status textToStatus (const std::string&);
@@ -92,6 +88,7 @@ public:
   void setAsNow (const std::string&);
   bool has (const std::string&) const;
   std::vector <std::string> all ();
+  const std::string identifier (bool shortened = false) const;
   const std::string get (const std::string&) const;
   const std::string& get_ref (const std::string&) const;
   int get_int (const std::string&) const;
@@ -119,7 +116,9 @@ public:
   status getStatus () const;
   void setStatus (status);
 
+#ifdef PRODUCT_TASKWARRIOR
   dateState getDateState (const std::string&) const;
+#endif
 
   int getTagCount () const;
   bool hasTag (const std::string&) const;
@@ -136,7 +135,9 @@ public:
 
 #ifdef PRODUCT_TASKWARRIOR
   void addDependency (int);
+#endif
   void addDependency (const std::string&);
+#ifdef PRODUCT_TASKWARRIOR
   void removeDependency (int);
   void removeDependency (const std::string&);
   void getDependencies (std::vector <int>&) const;
@@ -152,8 +153,10 @@ public:
   float urgency_c () const;
   float urgency ();
 
+#ifdef PRODUCT_TASKWARRIOR
   enum modType {modReplace, modPrepend, modAppend, modAnnotate};
   void modify (modType, bool text_required = false);
+#endif
 
 private:
   int determineVersion (const std::string&);
