@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -35,10 +35,8 @@ class Timer
 {
 public:
   Timer ();
-  Timer (const std::string&);
+  explicit Timer (const std::string&);
   ~Timer ();
-  Timer (const Timer&);
-  Timer& operator= (const Timer&);
 
   void start ();
   void stop ();
@@ -48,12 +46,10 @@ public:
   static unsigned long now ();
 
 private:
-  std::string    _description;
-  bool           _running;
-  struct timeval _start;
-  unsigned long  _total;
+  std::string    _description {"-"};
+  bool           _running     {false};
+  struct timeval _start       {};
+  unsigned long  _total       {0};
 };
 
 #endif
-
-////////////////////////////////////////////////////////////////////////////////
