@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2013 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -41,107 +41,57 @@ std::string Variant::dateFormat = "";
 bool Variant::searchCaseSensitive = true;
 bool Variant::searchUsingRegex = true;
 
-////////////////////////////////////////////////////////////////////////////////
-Variant::Variant ()
-: _type (type_boolean)
-, _bool (false)
-, _integer (0)
-, _real (0.0)
-, _string ("")
-, _date (0)
-, _duration (0)
-, _source ("")
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const Variant& other)
-: _type (other._type)
-, _bool (other._bool)
-, _integer (other._integer)
-, _real (other._real)
-, _string (other._string)
-, _date (other._date)
-, _duration (other._duration)
-, _source (other._source)
 {
+  _type     = other._type;
+  _bool     = other._bool;
+  _integer  = other._integer;
+  _real     = other._real;
+  _string   = other._string;
+  _date     = other._date;
+  _duration = other._duration;
+  _source   = other._source;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const bool value)
 : _type (Variant::type_boolean)
 , _bool (value)
-, _integer (0)
-, _real (0.0)
-, _string ("")
-, _date (0)
-, _duration (0)
-, _source ("")
 {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const int value)
 : _type (Variant::type_integer)
-, _bool (false)
 , _integer (value)
-, _real (0.0)
-, _string ("")
-, _date (0)
-, _duration (0)
-, _source ("")
 {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const double value)
 : _type (Variant::type_real)
-, _bool (false)
-, _integer (0)
 , _real (value)
-, _string ("")
-, _date (0)
-, _duration (0)
-, _source ("")
 {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const std::string& value)
 : _type (Variant::type_string)
-, _bool (false)
-, _integer (0)
-, _real (0.0)
 , _string (value)
-, _date (0)
-, _duration (0)
-, _source ("")
 {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const char* value)
 : _type (Variant::type_string)
-, _bool (false)
-, _integer (0)
-, _real (0.0)
-, _string (std::string (value))
-, _date (0)
-, _duration (0)
-, _source ("")
+, _string (value)
 {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Variant::Variant (const time_t value, const enum type new_type)
 : _type (new_type)
-, _bool (false)
-, _integer (0)
-, _real (0.0)
-, _string ("")
-, _date (0)
-, _duration (0)
-, _source ("")
 {
   switch (new_type)
   {
@@ -152,11 +102,6 @@ Variant::Variant (const time_t value, const enum type new_type)
   }
 }
 
-////////////////////////////////////////////////////////////////////////////////
-Variant::~Variant ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 void Variant::source (const std::string& input)
 {
@@ -172,17 +117,14 @@ const std::string& Variant::source () const
 ////////////////////////////////////////////////////////////////////////////////
 Variant& Variant::operator= (const Variant& other)
 {
-  if (this != &other)
-  {
-    _type     = other._type;
-    _bool     = other._bool;
-    _integer  = other._integer;
-    _real     = other._real;
-    _string   = other._string;
-    _date     = other._date;
-    _duration = other._duration;
-    _source   = other._source;
-  }
+  _type     = other._type;
+  _bool     = other._bool;
+  _integer  = other._integer;
+  _real     = other._real;
+  _string   = other._string;
+  _date     = other._date;
+  _duration = other._duration;
+  _source   = other._source;
 
   return *this;
 }
@@ -1788,68 +1730,10 @@ Variant::operator std::string () const
     return _string;
 
   case type_date:
-    {
-      struct tm* t = localtime (&_date);
-
-      std::stringstream s;
-      s.width (4);
-      s << t->tm_year + 1900;
-      s << '-';
-      s.width (2);
-      s.fill ('0');
-      s << t->tm_mon + 1;
-      s << '-';
-      s.width (2);
-      s.fill ('0');
-      s << t->tm_mday;
-      s << 'T';
-      s.width (2);
-      s.fill ('0');
-      s << t->tm_hour;
-      s << ':';
-      s.width (2);
-      s.fill ('0');
-      s << t->tm_min;
-      s << ':';
-      s.width (2);
-      s.fill ('0');
-      s << t->tm_sec;
-      return s.str ();
-    }
+    return ISO8601d (_date).toISOLocalExtended ();
 
   case type_duration:
-    {
-      time_t t = _duration;
-      if (t)
-      {
-        std::stringstream s;
-        s << 'P';
-
-        int years = t / (365 * 86400);  t -= years * 365 * 86400;
-        int days  = t / 86400;          t -= days        * 86400;
-
-        if (years) s << years << 'Y';
-        if (days)  s << days  << 'D';
-
-        int hours   = t / 3600;           t -= hours   * 3600;
-        int minutes = t /   60;           t -= minutes *   60;
-        int seconds = t;
-
-        if (hours || minutes || seconds)
-        {
-          s << 'T';
-          if (hours)   s << hours   << 'H';
-          if (minutes) s << minutes << 'M';
-          if (seconds) s << seconds << 'S';
-        }
-
-        return s.str ();
-      }
-      else
-      {
-        return "PT0S";
-      }
-    }
+    return ISO8601p (_duration).format ();
   }
 
   return "";
