@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +25,8 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <numeric>
 #include <ViewTask.h>
+#include <numeric>
 #include <Context.h>
 #include <Timer.h>
 #include <text.h>
@@ -354,7 +354,7 @@ std::string ViewTask::render (std::vector <Task>& data, std::vector <int>& seque
         if (c)
         {
           if (row_color.nontrivial ())
-            out += row_color.colorize (intra);
+            row_color._colorize (out, intra);
           else
             out += (odd ? intra_odd : intra_even);
         }
@@ -362,7 +362,7 @@ std::string ViewTask::render (std::vector <Task>& data, std::vector <int>& seque
         if (i < cells[c].size ())
           out += cells[c][i];
         else
-          out += row_color.colorize (std::string (widths[c], ' '));
+          row_color._colorize (out, std::string (widths[c], ' '));
       }
 
       out += (odd ? extra_odd : extra_even);
