@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,13 +25,14 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <ColDepends.h>
 #include <algorithm>
 #include <Context.h>
-#include <ColDepends.h>
 #include <text.h>
 #include <utf8.h>
 #include <i18n.h>
 #include <main.h>
+#include <stdlib.h>
 
 extern Context context;
 
@@ -39,7 +40,6 @@ extern Context context;
 ColumnDepends::ColumnDepends ()
 {
   _name      = "depends";
-  _type      = "string";
   _style     = "list";
   _label     = STRING_COLUMN_LABEL_DEP;
   _styles    = {"list",
@@ -49,12 +49,7 @@ ColumnDepends::ColumnDepends ()
                 "[3]",
                 context.config.get ("dependency.indicator")};
 
-  _hyphenate = context.config.getBoolean ("hyphenate");
-}
-
-////////////////////////////////////////////////////////////////////////////////
-ColumnDepends::~ColumnDepends ()
-{
+  _hyphenate = false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -123,37 +118,58 @@ void ColumnDepends::render (
   if (task.has (_name))
   {
     if (_style == "indicator")
+      renderStringRight (lines, width, color, context.config.get ("dependency.indicator"));
+    else
     {
-      lines.push_back (
-        color.colorize (
-          rightJustify (context.config.get ("dependency.indicator"), width)));
-      return;
-    }
+      std::vector <Task> blocking;
+      dependencyGetBlocking (task, blocking);
 
-    std::vector <Task> blocking;
-    dependencyGetBlocking (task, blocking);
+      if (_style == "count")
+        renderStringRight (lines, width, color, "[" + format (static_cast <int>(blocking.size ())) + "]");
 
-    if (_style == "count")
-    {
-      lines.push_back (
-        color.colorize (
-          rightJustify ("[" + format ((int)blocking.size ()) + "]", width)));
-    }
-    else if (_style == "default" ||
-             _style == "list")
-    {
-      std::vector <int> blocking_ids;
-      for (auto& t : blocking)
-        blocking_ids.push_back (t.id);
+      else if (_style == "default" ||
+               _style == "list")
+      {
+        std::vector <int> blocking_ids;
+        for (const auto& t : blocking)
+          blocking_ids.push_back (t.id);
 
-      std::string combined;
-      join (combined, " ", blocking_ids);
+        std::string combined;
+        join (combined, " ", blocking_ids);
 
-      std::vector <std::string> all;
-      wrapText (all, combined, width, _hyphenate);
+        std::vector <std::string> all;
+        wrapText (all, combined, width, _hyphenate);
 
-      for (auto& i : all)
-        lines.push_back (color.colorize (leftJustify (i, width)));
+        for (const auto& i : all)
+          renderStringLeft (lines, width, color, i);
+      }
+    }
+  }
+}
+
+////////////////////////////////////////////////////////////////////////////////
+void ColumnDepends::modify (Task& task, const std::string& value)
+{
+  // Parse IDs
+  std::vector <std::string> deps;
+  split (deps, value, ',');
+
+  // Apply or remove dendencies in turn.
+  for (auto& dep : deps)
+  {
+    if (dep[0] == '-')
+    {
+      if (dep.length () == 37)
+        task.removeDependency (dep.substr (1));
+      else
+        task.removeDependency (strtol (dep.substr (1).c_str (), NULL, 10));
+    }
+    else
+    {
+      if (dep.length () == 36)
+        task.addDependency (dep);
+      else
+        task.addDependency (strtol (dep.c_str (), NULL, 10));
     }
   }
 }
