@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,21 +27,17 @@
 #ifndef INCLUDED_COLDEPENDS
 #define INCLUDED_COLDEPENDS
 
-#include <vector>
-#include <string>
-#include <Column.h>
-#include <Color.h>
-#include <Task.h>
+#include <ColTypeString.h>
 
-class ColumnDepends : public Column
+class ColumnDepends : public ColumnTypeString
 {
 public:
   ColumnDepends ();
-  ~ColumnDepends ();
 
   void setStyle (const std::string&);
   void measure (Task&, unsigned int&, unsigned int&);
   void render (std::vector <std::string>&, Task&, int, Color&);
+  void modify (Task&, const std::string&);
 
 private:
   bool _hyphenate;
