@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,14 +25,11 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <stdlib.h>
-#include <Context.h>
 #include <ColDue.h>
+#include <stdlib.h>
 #include <text.h>
 #include <i18n.h>
 
-extern Context context;
-
 ////////////////////////////////////////////////////////////////////////////////
 ColumnDue::ColumnDue ()
 {
@@ -40,11 +37,6 @@ ColumnDue::ColumnDue ()
   _label     = STRING_COLUMN_LABEL_DUE;
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnDue::~ColumnDue ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Overriden so that style <----> label are linked.
 // Note that you can not determine which gets called first.
