@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,14 +27,12 @@
 #ifndef INCLUDED_COLENTRY
 #define INCLUDED_COLENTRY
 
-#include <ColDate.h>
+#include <ColTypeDate.h>
 
-class ColumnEntry : public ColumnDate
+class ColumnEntry : public ColumnTypeDate
 {
 public:
   ColumnEntry ();
-  ~ColumnEntry ();
-
   void setStyle (const std::string&);
 };
 
