@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,19 +25,15 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <math.h>
-#include <Context.h>
 #include <ColMask.h>
+#include <math.h>
 #include <text.h>
 #include <i18n.h>
 
-extern Context context;
-
 ////////////////////////////////////////////////////////////////////////////////
 ColumnMask::ColumnMask ()
 {
   _name       = "mask";
-  _type       = "string";
   _style      = "default";
   _label      = STRING_COLUMN_LABEL_MASK;
   _modifiable = false;
@@ -45,11 +41,6 @@ ColumnMask::ColumnMask ()
   _examples   = {"++++---"};
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnMask::~ColumnMask ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Set the minimum and maximum widths for the value.
 void ColumnMask::measure (Task& task, unsigned int& minimum, unsigned int& maximum)
@@ -68,11 +59,11 @@ void ColumnMask::measure (Task& task, unsigned int& minimum, unsigned int& maxim
 void ColumnMask::render (
   std::vector <std::string>& lines,
   Task& task,
-  int,
+  int width,
   Color& color)
 {
   if (task.has (_name))
-    lines.push_back (color.colorize (task.get ("mask")));
+    renderStringLeft (lines, width, color, task.get ("mask"));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
