@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,13 +27,12 @@
 #ifndef INCLUDED_COLMODIFIED
 #define INCLUDED_COLMODIFIED
 
-#include <ColDate.h>
+#include <ColTypeDate.h>
 
-class ColumnModified : public ColumnDate
+class ColumnModified : public ColumnTypeDate
 {
 public:
   ColumnModified ();
-  ~ColumnModified ();
 };
 
 #endif
