@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,29 +25,20 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <math.h>
-#include <Context.h>
 #include <ColParent.h>
+#include <math.h>
 #include <text.h>
 #include <i18n.h>
 
-extern Context context;
-
 ////////////////////////////////////////////////////////////////////////////////
 ColumnParent::ColumnParent ()
 {
   _name       = "parent";
-  _type       = "string";
   _style      = "long";
   _label      = STRING_COLUMN_LABEL_PARENT;
   _modifiable = false;
   _styles     = {"long", "short"};
-  _examples   = {"f30cb9c3-3fc0-483f-bfb2-3bf134f00694", "34f00694"};
-}
-
-////////////////////////////////////////////////////////////////////////////////
-ColumnParent::~ColumnParent ()
-{
+  _examples   = {"f30cb9c3-3fc0-483f-bfb2-3bf134f00694", "f30cb9c3"};
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -75,20 +66,13 @@ void ColumnParent::render (
   if (task.has (_name))
   {
     // f30cb9c3-3fc0-483f-bfb2-3bf134f00694  default
-    //                             34f00694  short
+    // f30cb9c3                              short
     if (_style == "default" ||
         _style == "long")
-    {
-      lines.push_back (color.colorize (leftJustify (task.get (_name), width)));
-    }
+      renderStringLeft (lines, width, color, task.get(_name));
 
     else if (_style == "short")
-    {
-      if (task.has (_name))
-        lines.push_back (color.colorize (leftJustify (task.get (_name).substr (28), width)));
-      else
-        lines.push_back (color.colorize (leftJustify ("", width)));
-    }
+      renderStringLeft (lines, width, color, task.get (_name).substr (0, 8));
   }
 }
 
