@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,20 +25,25 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <Context.h>
 #include <ColProject.h>
+#include <Context.h>
+#include <Eval.h>
+#include <Variant.h>
+#include <Lexer.h>
+#include <Filter.h>
+#include <Dates.h>
 #include <text.h>
 #include <utf8.h>
 #include <util.h>
 #include <i18n.h>
 
 extern Context context;
+extern Task& contextTask;
 
 ////////////////////////////////////////////////////////////////////////////////
 ColumnProject::ColumnProject ()
 {
   _name      = "project";
-  _type      = "string";
   _style     = "full";
   _label     = STRING_COLUMN_LABEL_PROJECT;
   _styles    = {"full", "parent", "indented"};
@@ -48,11 +53,6 @@ ColumnProject::ColumnProject ()
   _hyphenate = context.config.getBoolean ("hyphenate");
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnProject::~ColumnProject ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Set the minimum and maximum widths for the value.
 void ColumnProject::measure (Task& task, unsigned int& minimum, unsigned int& maximum)
@@ -107,8 +107,37 @@ void ColumnProject::render (
     std::vector <std::string> raw;
     wrapText (raw, project, width, _hyphenate);
 
-    for (auto& i : raw)
-      lines.push_back (color.colorize (leftJustify (i, width)));
+    for (const auto& i : raw)
+      renderStringLeft (lines, width, color, i);
+  }
+}
+
+////////////////////////////////////////////////////////////////////////////////
+void ColumnProject::modify (Task& task, const std::string& value)
+{
+  std::string label = "  [1;37;43mMODIFICATION[0m ";
+
+  // Only if it's a DOM ref, eval it first.
+  Lexer lexer (value);
+  std::string domRef;
+  Lexer::Type type;
+  if (lexer.token (domRef, type) &&
+      type == Lexer::Type::dom)
+  {
+    Eval e;
+    e.addSource (domSource);
+    e.addSource (namedDates);
+    contextTask = task;
+
+    Variant v;
+    e.evaluateInfixExpression (value, v);
+    task.set (_name, (std::string) v);
+    context.debug (label + _name + " <-- '" + (std::string) v + "' <-- '" + value + "'");
+  }
+  else
+  {
+    task.set (_name, value);
+    context.debug (label + _name + " <-- '" + value + "'");
   }
 }
 
