@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,35 +25,31 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <ColRecur.h>
 #include <Context.h>
 #include <ISO8601.h>
-#include <ColRecur.h>
+#include <Eval.h>
+#include <Variant.h>
+#include <Lexer.h>
+#include <Filter.h>
+#include <Dates.h>
 #include <text.h>
 #include <utf8.h>
 #include <i18n.h>
 
 extern Context context;
+extern Task& contextTask;
 
 ////////////////////////////////////////////////////////////////////////////////
 ColumnRecur::ColumnRecur ()
 {
   _name     = "recur";
-
-  // This is 'string', and not 'duration' to force the value to be stored as a
-  // raw duration, so that it can be reevaluated every time.
-  _type     = "string";
-
   _style    = "duration";
   _label    = STRING_COLUMN_LABEL_RECUR;
   _styles   = {"duration", "indicator"};
   _examples = {"weekly", context.config.get ("recurrence.indicator")};
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnRecur::~ColumnRecur ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Overriden so that style <----> label are linked.
 // Note that you can not determine which gets called first.
@@ -101,19 +97,43 @@ void ColumnRecur::render (
   {
     if (_style == "default" ||
         _style == "duration")
-    {
-      lines.push_back (
-        color.colorize (
-          rightJustify (
-            ISO8601p (task.get ("recur")).format (), width)));
-    }
+      renderStringRight (lines, width, color, ISO8601p (task.get ("recur")).format ());
+
     else if (_style == "indicator")
-    {
-      lines.push_back (
-        color.colorize (
-          rightJustify (context.config.get ("recurrence.indicator"), width)));
-    }
+      renderStringRight (lines, width, color, context.config.get ("recurrence.indicator"));
   }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+// The duration is stored in raw form, but it must still be valid,
+// and therefore is parsed first.
+void ColumnRecur::modify (Task& task, const std::string& value)
+{
+  // Try to evaluate 'value'.  It might work.
+  Variant evaluatedValue;
+  try
+  {
+    Eval e;
+    e.addSource (domSource);
+    e.addSource (namedDates);
+    contextTask = task;
+    e.evaluateInfixExpression (value, evaluatedValue);
+  }
+
+  catch (...)
+  {
+    evaluatedValue = Variant (value);
+  }
+
+  if (evaluatedValue.type () == Variant::type_duration)
+  {
+    // Store the raw value, for 'recur'.
+    std::string label = "  [1;37;43mMODIFICATION[0m ";
+    context.debug (label + _name + " <-- '" + value + "'");
+    task.set (_name, value);
+  }
+  else
+    throw format (STRING_TASK_INVALID_DUR, value);
+}
+
+////////////////////////////////////////////////////////////////////////////////
