@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,21 +27,18 @@
 #ifndef INCLUDED_COLRECUR
 #define INCLUDED_COLRECUR
 
-#include <vector>
-#include <string>
-#include <Column.h>
-#include <Color.h>
-#include <Task.h>
+#include <ColTypeString.h>
 
-class ColumnRecur : public Column
+// This is 'string', and not 'duration' to force the value to be stored as a
+// raw duration, so that it can be reevaluated every time.
+class ColumnRecur : public ColumnTypeString
 {
 public:
   ColumnRecur ();
-  ~ColumnRecur ();
-
   void setStyle (const std::string&);
   void measure (Task&, unsigned int&, unsigned int&);
   void render (std::vector <std::string>&, Task&, int, Color&);
+  void modify (Task&, const std::string&);
 
 private:
 };
