@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +25,8 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <Context.h>
 #include <ColStart.h>
+#include <Context.h>
 #include <text.h>
 #include <utf8.h>
 #include <i18n.h>
@@ -43,11 +43,6 @@ ColumnStart::ColumnStart ()
   _examples.push_back (context.config.get ("active.indicator"));
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnStart::~ColumnStart ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Overriden so that style <----> label are linked.
 // Note that you can not determine which gets called first.
@@ -75,7 +70,7 @@ void ColumnStart::measure (Task& task, unsigned int& minimum, unsigned int& maxi
         minimum = maximum = 0;
     }
     else
-      ColumnDate::measure (task, minimum, maximum);
+      ColumnTypeDate::measure (task, minimum, maximum);
   }
 }
 
@@ -91,13 +86,10 @@ void ColumnStart::render (
     if (_style == "active")
     {
       if (! task.has ("end"))
-        lines.push_back (
-          color.colorize (
-            rightJustify (
-              context.config.get ("active.indicator"), width)));
+        renderStringRight (lines, width, color, context.config.get ("active.indicator"));
     }
     else
-      ColumnDate::render (lines, task, width, color);
+      ColumnTypeDate::render (lines, task, width, color);
   }
 }
 
