@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,19 +25,15 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <Context.h>
 #include <ColStatus.h>
 #include <text.h>
 #include <i18n.h>
 #include <utf8.h>
 
-extern Context context;
-
 ////////////////////////////////////////////////////////////////////////////////
 ColumnStatus::ColumnStatus ()
 {
   _name     = "status";
-  _type     = "string";
   _style    = "long";
   _label    = STRING_COLUMN_LABEL_STATUS;
   _styles   = {"long", "short"};
@@ -45,11 +41,6 @@ ColumnStatus::ColumnStatus ()
                STRING_COLUMN_LABEL_STAT_P};
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnStatus::~ColumnStatus ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Overriden so that style <----> label are linked.
 // Note that you can not determine which gets called first.
@@ -116,7 +107,7 @@ void ColumnStatus::render (
     else if (status == Task::recurring) value = STRING_COLUMN_LABEL_STAT_R;
   }
 
-  lines.push_back (color.colorize (leftJustify (value, width)));
+  renderStringLeft (lines, width, color, value);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
