@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +25,8 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <Context.h>
 #include <ColString.h>
+#include <Context.h>
 #include <text.h>
 #include <i18n.h>
 
@@ -50,11 +50,6 @@ ColumnString::ColumnString ()
   _hyphenate = context.config.getBoolean ("hyphenate");
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnString::~ColumnString ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // ColumnString is unique - it copies the report name into the label.  This is
 // a kludgy reuse of an otherwise unused member.
@@ -98,7 +93,7 @@ void ColumnString::render (
     wrapText (raw, value, width, _hyphenate);
 
     for (auto& i : raw)
-      lines.push_back (color.colorize (leftJustify (i, width)));
+      renderStringLeft (lines, width, color, i);
   }
   else if (_style == "right")
   {
@@ -106,16 +101,14 @@ void ColumnString::render (
     wrapText (raw, value, width, _hyphenate);
 
     for (auto& i : raw)
-      lines.push_back (color.colorize (rightJustify (i, width)));
+      renderStringRight (lines, width, color, i);
   }
+
   else if (_style == "left_fixed")
-  {
-    lines.push_back (leftJustify (value, width));
-  }
+    renderStringLeft (lines, width, color, value);
+
   else if (_style == "right_fixed")
-  {
-    lines.push_back (rightJustify (value, width));
-  }
+    renderStringRight (lines, width, color, value);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
