@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,19 +25,15 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <math.h>
-#include <Context.h>
 #include <ColUUID.h>
+#include <math.h>
 #include <text.h>
 #include <i18n.h>
 
-extern Context context;
-
 ////////////////////////////////////////////////////////////////////////////////
 ColumnUUID::ColumnUUID ()
 {
   _name       = "uuid";
-  _type       = "string";
   _style      = "long";
   _label      = STRING_COLUMN_LABEL_UUID;
   _modifiable = false;
@@ -45,11 +41,6 @@ ColumnUUID::ColumnUUID ()
   _examples   = {"f30cb9c3-3fc0-483f-bfb2-3bf134f00694", "f30cb9c3"};
 }
 
-////////////////////////////////////////////////////////////////////////////////
-ColumnUUID::~ColumnUUID ()
-{
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Set the minimum and maximum widths for the value.
 void ColumnUUID::measure (Task&, unsigned int& minimum, unsigned int& maximum)
@@ -67,14 +58,16 @@ void ColumnUUID::render (
   int width,
   Color& color)
 {
+  // No need to check the presence of UUID - all tasks have one.
+
   // f30cb9c3-3fc0-483f-bfb2-3bf134f00694  default
   // f30cb9c3                              short
   if (_style == "default" ||
       _style == "long")
-    lines.push_back (color.colorize (leftJustify (task.get (_name), width)));
+    renderStringLeft (lines, width, color, task.get (_name));
 
   else if (_style == "short")
-    lines.push_back (color.colorize (leftJustify (task.get (_name).substr (0, 8), width)));
+    renderStringLeft (lines, width, color, task.get (_name).substr (0, 8));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
