@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,9 +25,10 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <algorithm>
-#include <Context.h>
 #include <Column.h>
+#include <algorithm>
+#include <set>
+#include <Context.h>
 #include <ColDepends.h>
 #include <ColDescription.h>
 #include <ColDue.h>
@@ -103,7 +104,7 @@ Column* Column::factory (const std::string& name, const std::string& report)
   else if (column_name == "string")      c = new ColumnString ();
 
   // UDA.
-  else if (context.config.get ("uda." + column_name + ".type") != "")
+  else if (context.config.has ("uda." + column_name + ".type"))
     c = Column::uda (column_name);
 
   else
@@ -148,54 +149,77 @@ void Column::factory (std::map <std::string, Column*>& all)
 void Column::uda (std::map <std::string, Column*>& all)
 {
   // For each UDA, instantiate and initialize ColumnUDA().
-  std::map <std::string, int> udas;
+  std::set <std::string> udas;
 
-  for (auto& i : context.config)
+  for (const auto& i : context.config)
   {
     if (i.first.substr (0, 4) == "uda.")
     {
-      std::string::size_type period = 4;
+      std::string::size_type period = 4; // One byte after the first '.'.
+
       if ((period = i.first.find ('.', period)) != std::string::npos)
-        udas[i.first.substr (4, period - 4)] = 0;
+        udas.insert (i.first.substr (4, period - 4));
     }
   }
 
-  for (auto& uda : udas)
+  for (const auto& uda : udas)
   {
-    if (all.find (uda.first) != all.end ())
-      throw format (STRING_UDA_COLLISION, uda.first);
+    if (all.find (uda) != all.end ())
+      throw format (STRING_UDA_COLLISION, uda);
 
-    Column* c = Column::uda (uda.first);
-    all[c->_name] = c;
+    Column* c = Column::uda (uda);
+    if (c)
+      all[c->_name] = c;
   }
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 Column* Column::uda (const std::string& name)
 {
-  ColumnUDA* c = new ColumnUDA ();
-  c->_name = name;
+  auto type   = context.config.get ("uda." + name + ".type");
+  auto label  = context.config.get ("uda." + name + ".label");
+  auto values = context.config.get ("uda." + name + ".values");
 
-  std::string key = "uda." + name + ".type";
-  c->_type = context.config.get (key);
-  if (c->_type == "")
-    context.error (format  (STRING_UDA_TYPE_MISSING, name));
+  if (type == "string")
+  {
+    auto c = new ColumnUDAString ();
+    c->_name = name;
+    c->_label = label;
+    if (values != "")
+      split (c->_values, values, ',');
+    return c;
+  }
+  else if (type == "numeric")
+  {
+    auto c = new ColumnUDANumeric ();
+    c->_name = name;
+    c->_label = label;
+    if (values != "")
+      split (c->_values, values, ',');
+    return c;
+  }
+  else if (type == "date")
+  {
+    auto c = new ColumnUDADate ();
+    c->_name = name;
+    c->_label = label;
+    if (values != "")
+      split (c->_values, values, ',');
+    return c;
+  }
+  else if (type == "duration")
+  {
+    auto c = new ColumnUDADuration ();
+    c->_name = name;
+    c->_label = label;
+    if (values != "")
+      split (c->_values, values, ',');
+    return c;
+  }
+  else if (type != "")
+    throw std::string (STRING_UDA_TYPE);
 
-  if (c->_type != "string"   &&
-      c->_type != "date"     &&
-      c->_type != "duration" &&
-      c->_type != "numeric")
-    context.error (STRING_UDA_TYPE);
-
-  key = "uda." + name + ".label";
-  if (context.config.get (key) != "")
-    c->_label = context.config.get (key);
-
-  key = "uda." + name + ".values";
-  if (context.config.get (key) != "")
-    split (c->_values, context.config.get (key), ',');
-
-  return c;
+  return NULL;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -223,7 +247,7 @@ void Column::renderHeader (
   Color& color)
 {
   if (context.verbose ("label") &&
-     nontrivial (_label))
+      _label != "")
   {
     // Create a basic label.
     std::string header;
@@ -259,16 +283,60 @@ void Column::setStyle (const std::string& style)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-bool Column::validate (std::string& input)
+bool Column::validate (const std::string& input) const
 {
   return input.length () ? true : false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// No L10N.
-bool Column::can_modify ()
+// All integer values are right-justified.
+void Column::renderInteger (
+  std::vector <std::string>& lines,
+  int width,
+  Color& color,
+  int value)
 {
-  return false;
+  lines.push_back (
+    color.colorize (
+      rightJustify (value, width)));
+}
+
+////////////////////////////////////////////////////////////////////////////////
+// All floating point values are right-justified.
+void Column::renderDouble (
+  std::vector <std::string>& lines,
+  int width,
+  Color& color,
+  double value)
+{
+  lines.push_back (
+    color.colorize (
+      rightJustify (
+        format (value, 4, 3), width)));
+}
+
+////////////////////////////////////////////////////////////////////////////////
+void Column::renderStringLeft (
+  std::vector <std::string>& lines,
+  int width,
+  Color& color,
+  const std::string& value)
+{
+  lines.push_back (
+    color.colorize (
+      leftJustify (value, width)));
+}
+
+////////////////////////////////////////////////////////////////////////////////
+void Column::renderStringRight (
+  std::vector <std::string>& lines,
+  int width,
+  Color& color,
+  const std::string& value)
+{
+  lines.push_back (
+    color.colorize (
+      rightJustify (value, width)));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
