@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -57,14 +57,19 @@ public:
   virtual void setLabel  (const std::string& value) { _label = value;  }
   virtual void setReport (const std::string& value) { _report = value; }
 
-  virtual bool validate (std::string&);
+  virtual bool validate (const std::string&) const;
   virtual void measure (const std::string&, unsigned int&, unsigned int&)           {};
   virtual void measure (Task&, unsigned int&, unsigned int&)                        {};
   virtual void renderHeader (std::vector <std::string>&, int, Color&);
   virtual void render (std::vector <std::string>&, const std::string&, int, Color&) {};
   virtual void render (std::vector <std::string>&, Task&, int, Color&)              {};
-  virtual bool can_modify ();
-  virtual std::string modify (std::string& input)                                   { return input; };
+  virtual void modify (Task&, const std::string&)                                   {};
+
+protected:
+  void renderInteger     (std::vector <std::string>&, int, Color&, int);
+  void renderDouble      (std::vector <std::string>&, int, Color&, double);
+  void renderStringLeft  (std::vector <std::string>&, int, Color&, const std::string&);
+  void renderStringRight (std::vector <std::string>&, int, Color&, const std::string&);
 
 protected:
   std::string _name;
