@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdColumns.h>
 #include <algorithm>
 #include <Context.h>
 #include <ViewText.h>
@@ -32,7 +33,6 @@
 #include <text.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdColumns.h>
 
 extern Context context;
 
@@ -73,6 +73,7 @@ int CmdColumns::execute (std::string& output)
   formats.width (context.getWidth ());
   formats.add (Column::factory ("string", STRING_COLUMN_LABEL_COLUMN));
   formats.add (Column::factory ("string", STRING_COLUMN_LABEL_TYPE));
+  formats.add (Column::factory ("string", STRING_COLUMN_LABEL_MODIFY));
   formats.add (Column::factory ("string", STRING_COLUMN_LABEL_STYLES));
   formats.add (Column::factory ("string", STRING_COLUMN_LABEL_EXAMPLES));
 
@@ -99,8 +100,9 @@ int CmdColumns::execute (std::string& output)
         int row = formats.addRow ();
         formats.set (row, 0, i == 0 ? name : "");
         formats.set (row, 1, i == 0 ? context.columns[name]->type () : "");
-        formats.set (row, 2, styles[i] + (i == 0 ? "*" : ""));
-        formats.set (row, 3, i < examples.size () ? examples[i] : "");
+        formats.set (row, 2, i == 0 ? (context.columns[name]->modifiable () ? STRING_COLUMN_LABEL_MODIFY : STRING_COLUMN_LABEL_NOMODIFY) : "");
+        formats.set (row, 3, styles[i] + (i == 0 ? "*" : ""));
+        formats.set (row, 4, i < examples.size () ? examples[i] : "");
       }
     }
   }
@@ -108,11 +110,12 @@ int CmdColumns::execute (std::string& output)
   int row = formats.addRow ();
   formats.set (row, 0, "<uda>");
   formats.set (row, 1, "<type>");
-  formats.set (row, 2, "default*");
+  formats.set (row, 2, "Modifiable");
+  formats.set (row, 3, "default*");
 
   row = formats.addRow ();
   formats.set (row, 0, "");
-  formats.set (row, 2, "indicator");
+  formats.set (row, 3, "indicator");
 
   output = optionalBlankLine ()
          + formats.render ()
