@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdDenotate.h>
 #include <iostream>
 #include <Context.h>
 #include <Filter.h>
@@ -32,7 +33,6 @@
 #include <util.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdDenotate.h>
 
 extern Context context;
 
@@ -124,10 +124,10 @@ int CmdDenotate::execute (std::string&)
       }
     }
 
-    if (before != task)
+    if (before.data != task.data)
     {
       std::string question = format (STRING_CMD_DENO_CONFIRM,
-                                     task.id,
+                                     task.identifier (true),
                                      task.get ("description"));
 
       if (permission (taskDifferences (before, task) + question, filtered.size ()))
