@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdDiagnostics.h>
 #include <iomanip>
 #include <sstream>
 #include <algorithm>
@@ -43,7 +44,6 @@
 #include <gnutls/gnutls.h>
 #endif
 
-#include <CmdDiagnostics.h>
 
 extern Context context;
 
@@ -305,29 +305,88 @@ int CmdDiagnostics::execute (std::string& output)
       << "\n\n";
 
   // Disaply hook status.
+  Path hookLocation (context.config.get ("data.location"));
+  hookLocation += "hooks";
+
   out << bold.colorize (STRING_CMD_DIAG_HOOKS)
       << "\n"
-      << "    Scripts: "
+      << "     System: "
       << (context.config.getBoolean ("hooks") ? STRING_CMD_DIAG_HOOK_ENABLE : STRING_CMD_DIAG_HOOK_DISABLE)
+      << "\n"
+      << "   Location: "
+      << static_cast <std::string> (hookLocation)
       << "\n";
 
-  std::vector <std::string> hooks = context.hooks.list ();
+  auto hooks = context.hooks.list ();
   if (hooks.size ())
   {
+    unsigned int longest = 0;
+    for (auto& hook : hooks)
+      if (hook.length () > longest)
+        longest = hook.length ();
+    longest -= hookLocation._data.length () + 1;
+
+    out << "     Active: ";
+    int count = 0;
     for (auto& hook : hooks)
     {
       Path p (hook);
-      std::string name = p.name ();
-      out << "             "
-          << hook
-          << (p.executable () ? format (" ({1})", STRING_CMD_DIAG_HOOK_EXEC) : format (" ({1})", STRING_CMD_DIAG_HOOK_NO_EXEC))
-          << (p.is_link () ? format (" ({1})", STRING_CMD_DIAG_HOOK_SYMLINK) : "")
-          << ((name.substr (0, 6) == "on-add" ||
-               name.substr (0, 9) == "on-modify" ||
-               name.substr (0, 9) == "on-launch" ||
-               name.substr (0, 7) == "on-exit") ? "" : format (" ({1})", STRING_CMD_DIAG_HOOK_NAME))
-          << "\n";
+      if (! p.is_directory ())
+      {
+        std::string name = p.name ();
+
+        if (p.executable () &&
+            (name.substr (0, 6) == "on-add"    ||
+             name.substr (0, 9) == "on-modify" ||
+             name.substr (0, 9) == "on-launch" ||
+             name.substr (0, 7) == "on-exit"))
+        {
+          out << (count++ ? "             " : "");
+
+          out.width (longest);
+          out << std::left << name
+              << format (" ({1})", STRING_CMD_DIAG_HOOK_EXEC)
+              << (p.is_link () ? format (" ({1})", STRING_CMD_DIAG_HOOK_SYMLINK) : "")
+              << "\n";
+        }
+      }
     }
+
+    if (! count)
+      out << "\n";
+
+    out << "   Inactive: ";
+    count = 0;
+    for (auto& hook : hooks)
+    {
+      Path p (hook);
+      if (! p.is_directory ())
+      {
+        std::string name = p.name ();
+
+        if (! p.executable () ||
+            (name.substr (0, 6) != "on-add"    &&
+             name.substr (0, 9) != "on-modify" &&
+             name.substr (0, 9) != "on-launch" &&
+             name.substr (0, 7) != "on-exit"))
+        {
+          out << (count++ ? "             " : "");
+
+          out.width (longest);
+          out << std::left << name
+              << (p.executable () ? format (" ({1})", STRING_CMD_DIAG_HOOK_EXEC) : format (" ({1})", STRING_CMD_DIAG_HOOK_NO_EXEC))
+              << (p.is_link () ? format (" ({1})", STRING_CMD_DIAG_HOOK_SYMLINK) : "")
+              << ((name.substr (0, 6) == "on-add" ||
+                   name.substr (0, 9) == "on-modify" ||
+                   name.substr (0, 9) == "on-launch" ||
+                   name.substr (0, 7) == "on-exit") ? "" : format (" ({1})", STRING_CMD_DIAG_HOOK_NAME))
+              << "\n";
+        }
+      }
+    }
+
+    if (! count)
+      out << "\n";
   }
   else
     out << format ("             ({1})\n", STRING_CMD_DIAG_NONE);
@@ -337,47 +396,87 @@ int CmdDiagnostics::execute (std::string& output)
   // Verify UUIDs are all unique.
   out << bold.colorize (STRING_CMD_DIAG_TESTS)
       << "\n";
+
+  // Determine terminal details.
+  const char* term = getenv ("TERM");
+  out << "      $TERM: "
+      << (term ? term : STRING_CMD_DIAG_NONE)
+      << " ("
+      << context.getWidth ()
+      << "x"
+      << context.getHeight ()
+      << ")\n";
+
+  // Scan tasks for duplicate UUIDs.
+  std::vector <Task> all = context.tdb2.all_tasks ();
+  std::map <std::string, int> seen;
+  std::vector <std::string> dups;
+  std::string uuid;
+  for (auto& i : all)
   {
-    // Determine terminal details.
-    const char* term = getenv ("TERM");
-    out << "      $TERM: "
-        << (term ? term : STRING_CMD_DIAG_NONE)
-        << " ("
-        << context.getWidth ()
-        << "x"
-        << context.getHeight ()
-        << ")\n";
-
-    // Scan tasks for duplicate UUIDs.
-    std::vector <Task> all = context.tdb2.all_tasks ();
-    std::map <std::string, int> seen;
-    std::vector <std::string> dups;
-    std::string uuid;
-    for (auto& i : all)
-    {
-      uuid = i.get ("uuid");
-      if (seen.find (uuid) != seen.end ())
-        dups.push_back (uuid);
-      else
-         seen[uuid] = 0;
-    }
-
-    out << "       Dups: "
-        << format (STRING_CMD_DIAG_UUID_SCAN, all.size ())
-        << "\n";
-
-    if (dups.size ())
-    {
-      for (auto& d : dups)
-        out << "             " << format (STRING_CMD_DIAG_UUID_DUP, d) << "\n";
-    }
+    uuid = i.get ("uuid");
+    if (seen.find (uuid) != seen.end ())
+      dups.push_back (uuid);
     else
+       seen[uuid] = 0;
+  }
+
+  out << "       Dups: "
+      << format (STRING_CMD_DIAG_UUID_SCAN, all.size ())
+      << "\n";
+
+  if (dups.size ())
+  {
+    for (auto& d : dups)
+      out << "             " << format (STRING_CMD_DIAG_UUID_DUP, d) << "\n";
+  }
+  else
+  {
+    out << "             " << STRING_CMD_DIAG_UUID_NO_DUP
+        << "\n";
+  }
+
+
+  // Check all the UUID references
+
+  bool noBrokenRefs = true;
+  out << " Broken ref: "
+      << format (STRING_CMD_DIAG_REF_SCAN, all.size ())
+      << "\n";
+
+  for (auto& task : all)
+  {
+    // Check dependencies
+    std::vector <std::string> dependencies;
+    task.getDependencies(dependencies);
+
+    for (auto& uuid : dependencies)
     {
-      out << "             " << STRING_CMD_DIAG_UUID_NO_DUP
+      if (! context.tdb2.has (uuid))
+      {
+        out << "             "
+            << format (STRING_CMD_DIAG_MISS_DEP, task.get ("uuid"), uuid)
+            << "\n";
+        noBrokenRefs = false;
+      }
+    }
+
+    // Check recurrence parent
+    std::string parentUUID = task.get ("parent");
+
+    if (parentUUID != "" && ! context.tdb2.has (parentUUID))
+    {
+      out << "             "
+          << format (STRING_CMD_DIAG_MISS_PAR, task.get ("uuid"), parentUUID)
           << "\n";
+      noBrokenRefs = false;
     }
   }
 
+  if (noBrokenRefs)
+    out << "             " << STRING_CMD_DIAG_REF_OK
+        << "\n";
+
   out << "\n";
   output = out.str ();
   return 0;
