@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdDuplicate.h>
 #include <iostream>
 #include <Context.h>
 #include <Filter.h>
@@ -32,7 +33,6 @@
 #include <util.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdDuplicate.h>
 
 extern Context context;
 
@@ -88,7 +88,7 @@ int CmdDuplicate::execute (std::string&)
       dup.remove ("recur");
       dup.remove ("until");
       dup.remove ("imask");
-      std::cout << format (STRING_CMD_DUPLICATE_NON_REC, task.id)
+      std::cout << format (STRING_CMD_DUPLICATE_NON_REC, task.identifier ())
           << "\n";
     }
 
@@ -96,7 +96,7 @@ int CmdDuplicate::execute (std::string&)
     else if (dup.getStatus () == Task::recurring)
     {
       dup.remove ("mask");
-      std::cout << format (STRING_CMD_DUPLICATE_REC, task.id)
+      std::cout << format (STRING_CMD_DUPLICATE_REC, task.identifier ())
           << "\n";
     }
 
@@ -106,7 +106,7 @@ int CmdDuplicate::execute (std::string&)
     dup.modify (Task::modAnnotate);
 
     if (permission (format (STRING_CMD_DUPLICATE_CONFIRM,
-                            task.id,
+                            task.identifier (true),
                             task.get ("description")),
                     filtered.size ()))
     {
@@ -114,9 +114,14 @@ int CmdDuplicate::execute (std::string&)
       ++count;
       feedback_affected (STRING_CMD_DUPLICATE_TASK, task);
 
-      if (context.verbose ("new-id"))
+      auto status = dup.getStatus ();
+      if (context.verbose ("new-id") &&
+          (status == Task::pending ||
+           status == Task::waiting))
         std::cout << format (STRING_CMD_ADD_FEEDBACK, dup.id) + "\n";
-      else if (context.verbose ("new-uuid"))
+
+      else if (context.verbose ("new-uuid") &&
+               status != Task::recurring)
         std::cout << format (STRING_CMD_ADD_FEEDBACK, dup.get ("uuid")) + "\n";
 
       if (context.verbose ("project"))
