@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,14 +25,17 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdEdit.h>
 #include <iostream>
 #include <sstream>
-#include <stdlib.h>
+#include <cstdlib>
 #include <cstring>
 #include <algorithm>
 #include <unistd.h>
+#include <cerrno>
 #include <ISO8601.h>
 #include <Context.h>
+#include <Lexer.h>
 #include <Filter.h>
 #include <Nibbler.h>
 #include <i18n.h>
@@ -40,7 +43,6 @@
 #include <util.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdEdit.h>
 #include <JSON.h>
 
 extern Context context;
@@ -73,10 +75,16 @@ int CmdEdit::execute (std::string&)
   std::vector <Task> filtered;
   filter.subset (filtered);
 
+  if (! filtered.size ())
+  {
+    context.footnote (STRING_FEEDBACK_NO_MATCH);
+    return 1;
+  }
+
   // Find number of matching tasks.
   for (auto& task : filtered)
   {
-    CmdEdit::editResult result = editFile (task);
+    auto result = editFile (task);
     if (result == CmdEdit::editResult::error)
       break;
     else if (result == CmdEdit::editResult::changes)
@@ -101,7 +109,7 @@ std::string CmdEdit::findValue (
         found + name.length (),
         eol - (found + name.length ()));
 
-      return trim (value, "\t ");
+      return Lexer::trim (value, "\t ");
     }
   }
 
@@ -122,7 +130,7 @@ std::string CmdEdit::findMultilineValue (
     {
       std::string value = text.substr (start + startMarker.length (),
                                        end - (start + startMarker.length ()));
-      return trim (value, "\t ");
+      return Lexer::trim (value, "\\\t ");
     }
   }
   return "";
@@ -149,7 +157,7 @@ std::vector <std::string> CmdEdit::findValues (
           eol - (found + name.length ()));
 
         found = eol - 1;
-        results.push_back (trim (value, "\t "));
+        results.push_back (Lexer::trim (value, "\t "));
       }
     }
   }
@@ -213,12 +221,12 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
 
   before << "# " << STRING_EDIT_TABLE_HEADER_1 << "\n"
          << "# " << STRING_EDIT_TABLE_HEADER_2 << "\n"
-         << "# ID:                " << task.id                                          << "\n"
-         << "# UUID:              " << task.get ("uuid")                                << "\n"
-         << "# Status:            " << ucFirst (Task::statusToText (task.getStatus ())) << "\n"  // L10N safe ucFirst.
-         << "# Mask:              " << task.get ("mask")                                << "\n"
-         << "# iMask:             " << task.get ("imask")                               << "\n"
-         << "  Project:           " << task.get ("project")                             << "\n";
+         << "# ID:                " << task.id                                                 << "\n"
+         << "# UUID:              " << task.get ("uuid")                                       << "\n"
+         << "# Status:            " << Lexer::ucFirst (Task::statusToText (task.getStatus ())) << "\n"
+         << "# Mask:              " << task.get ("mask")                                       << "\n"
+         << "# iMask:             " << task.get ("imask")                                      << "\n"
+         << "  Project:           " << task.get ("project")                                    << "\n";
 
   std::vector <std::string> tags;
   task.getTags (tags);
@@ -628,7 +636,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     auto eol = after.find ("\n", found + 1);
     if (eol != std::string::npos)
     {
-      std::string value = trim (after.substr (
+      std::string value = Lexer::trim (after.substr (
         found,
         eol - found), "\t ");
 
@@ -658,7 +666,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
         }
         while (annotations.find (name.str ()) != annotations.end ());
 
-        std::string text = trim (value.substr (gap + 4), "\t ");
+        std::string text = Lexer::trim (value.substr (gap + 4), "\t ");
         annotations.insert (std::make_pair (name.str (), json::decode (text)));
       }
     }
@@ -735,8 +743,8 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     auto colon = orphan.find (':');
     if (colon != std::string::npos)
     {
-      std::string name  = trim (orphan.substr (0, colon),  "\t ");
-      std::string value = trim (orphan.substr (colon + 1), "\t ");
+      std::string name  = Lexer::trim (orphan.substr (0, colon),  "\t ");
+      std::string value = Lexer::trim (orphan.substr (colon + 1), "\t ");
 
       if (value != "")
         task.set (name, value);
