@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,11 +25,11 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdExport.h>
 #include <Context.h>
 #include <Filter.h>
 #include <main.h>
 #include <i18n.h>
-#include <CmdExport.h>
 
 extern Context context;
 
@@ -79,18 +79,19 @@ int CmdExport::execute (std::string& output)
     output += "[\n";
 
   int counter = 0;
-  for (auto task = filtered.begin (); task != filtered.end (); ++task)
+  for (auto& task : filtered)
   {
-    if (task != filtered.begin ())
-      {
-        if (json_array)
-          output += ",";
-        output += "\n";
-      }
+    if (counter)
+    {
+      if (json_array)
+        output += ",";
+      output += "\n";
+    }
 
-    output += task->composeJSON (true);
+    output += task.composeJSON (true);
 
-    if (limit && ++counter >= limit)
+    ++counter;
+    if (limit && counter >= limit)
       break;
   }
 
