@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,12 +25,13 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdGet.h>
 #include <Variant.h>
 #include <Context.h>
+#include <DOM.h>
 #include <main.h>
 #include <text.h>
 #include <i18n.h>
-#include <CmdGet.h>
 
 extern Context context;
 
@@ -67,7 +68,7 @@ int CmdGet::execute (std::string& output)
       {
         Task t;
         Variant result;
-        if (context.dom.get (arg.attribute ("raw"), t, result))
+        if (getDOM (arg.attribute ("raw"), t, result))
           results.push_back ((std::string) result);
         else
           results.push_back ("");
