@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,13 +25,14 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
-#include <algorithm>
 #include <CmdHelp.h>
+#include <algorithm>
 #include <ViewText.h>
 #include <Context.h>
 #include <i18n.h>
 #include <text.h>
 #include <util.h>
+#include <iostream> // TODO Remove
 
 extern Context context;
 
@@ -39,7 +40,7 @@ extern Context context;
 CmdHelp::CmdHelp ()
 {
   _keyword               = "help";
-  _usage                 = "task          help";
+  _usage                 = "task          help ['usage']";
   _description           = STRING_CMD_HELP_USAGE;
   _read_only             = true;
   _displays_id           = false;
@@ -47,12 +48,29 @@ CmdHelp::CmdHelp ()
   _uses_context          = false;
   _accepts_filter        = false;
   _accepts_modifications = false;
-  _accepts_miscellaneous = false;
+  _accepts_miscellaneous = true;
   _category              = Command::Category::misc;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 int CmdHelp::execute (std::string& output)
+{
+  auto words = context.cli2.getWords ();
+  if (words.size () == 1 && closeEnough ("usage", words[0]))
+    output = "\n"
+           + composeUsage ()
+           + "\n";
+  else
+    output = "\n"
+           + composeUsage ()
+           + "\n"
+           + STRING_CMD_HELP_TEXT;
+
+  return 0;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+std::string CmdHelp::composeUsage () const
 {
   ViewText view;
   view.width (context.getWidth ());
@@ -110,12 +128,7 @@ int CmdHelp::execute (std::string& output)
     }
   }
 
-  output = "\n"
-         + view.render ()
-         + "\n"
-         + STRING_CMD_HELP_TEXT;
-
-  return 0;
+  return view.render ();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
