@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdHistory.h>
 #include <sstream>
 #include <Context.h>
 #include <Filter.h>
@@ -33,7 +34,6 @@
 #include <text.h>
 #include <i18n.h>
 #include <ISO8601.h>
-#include <CmdHistory.h>
 
 extern Context context;
 
@@ -111,8 +111,11 @@ int CmdHistoryMonthly::execute (std::string& output)
   view.add (Column::factory ("string.right", STRING_CMD_HISTORY_DEL));
   view.add (Column::factory ("string.right", STRING_CMD_HISTORY_NET));
 
-  Color label (context.config.get ("color.label"));
-  view.colorHeader (label);
+  if (context.color ())
+  {
+    Color label (context.config.get ("color.label"));
+    view.colorHeader (label);
+  }
 
   int totalAdded     = 0;
   int totalCompleted = 0;
@@ -272,8 +275,11 @@ int CmdHistoryAnnual::execute (std::string& output)
   view.add (Column::factory ("string.right", STRING_CMD_HISTORY_DEL));
   view.add (Column::factory ("string.right", STRING_CMD_HISTORY_NET));
 
-  Color label (context.config.get ("color.label"));
-  view.colorHeader (label);
+  if (context.color ())
+  {
+    Color label (context.config.get ("color.label"));
+    view.colorHeader (label);
+  }
 
   int totalAdded     = 0;
   int totalCompleted = 0;
