@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,8 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdImport.h>
+#include <CmdModify.h>
 #include <iostream>
 #include <sstream>
 #include <Context.h>
@@ -33,8 +35,6 @@
 #include <util.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdImport.h>
-#include <CmdModify.h>
 
 extern Context context;
 
@@ -60,10 +60,6 @@ int CmdImport::execute (std::string&)
   int rc = 0;
   int count = 0;
 
-  Filter filter;
-  if (filter.hasFilter ())
-    throw std::string (STRING_ERROR_NO_FILTER);
-
   // Get filenames from command line arguments.
   std::vector <std::string> words = context.cli2.getWords ();
   if (! words.size () || (words.size () == 1 && words[0] == "-"))
@@ -209,7 +205,7 @@ void CmdImport::importSingleTask (json::object* obj)
     if (hasGeneratedEnd)
       task.set ("end", before.get ("end"));
 
-    if (before != task)
+    if (before.data != task.data)
     {
       CmdModify modHelper;
       modHelper.checkConsistency (before, task);
