@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdInfo.h>
 #include <sstream>
 #include <stdlib.h>
 #include <math.h>
@@ -34,7 +35,6 @@
 #include <main.h>
 #include <text.h>
 #include <i18n.h>
-#include <CmdInfo.h>
 
 extern Context context;
 
@@ -119,7 +119,7 @@ int CmdInfo::execute (std::string& output)
     view.set (row, 0, STRING_COLUMN_LABEL_ID);
     view.set (row, 1, (task.id ? format (task.id) : "-"));
 
-    std::string status = ucFirst (Task::statusToText (task.getStatus ()));  // L10N safe ucFirst.
+    std::string status = Lexer::ucFirst (Task::statusToText (task.getStatus ()));
 
     // description
     Color c;
@@ -362,28 +362,31 @@ int CmdInfo::execute (std::string& output)
     std::string type;
     for (auto& att: all)
     {
-      Column* col = context.columns[att];
-      if (col && col->is_uda ())
+      if (context.columns.find (att) != context.columns.end ())
       {
-        std::string value = task.get (att);
-        if (value != "")
+        Column* col = context.columns[att];
+        if (col->is_uda ())
         {
-          row = view.addRow ();
-          view.set (row, 0, col->label ());
-
-          if (type == "date")
-            value = ISO8601d (value).toString (dateformat);
-          else if (type == "duration")
+          std::string value = task.get (att);
+          if (value != "")
           {
-            ISO8601p iso;
-            std::string::size_type cursor = 0;
-            if (iso.parse (value, cursor))
-              value = (std::string) Variant ((time_t) iso, Variant::type_duration);
-            else
-              value = "PT0S";
-          }
+            row = view.addRow ();
+            view.set (row, 0, col->label ());
 
-          view.set (row, 1, value);
+            if (type == "date")
+              value = ISO8601d (value).toString (dateformat);
+            else if (type == "duration")
+            {
+              ISO8601p iso;
+              std::string::size_type cursor = 0;
+              if (iso.parse (value, cursor))
+                value = (std::string) Variant ((time_t) iso, Variant::type_duration);
+              else
+                value = "PT0S";
+            }
+
+            view.set (row, 1, value);
+          }
         }
       }
     }
@@ -393,7 +396,7 @@ int CmdInfo::execute (std::string& output)
     for (auto& att : all)
     {
       if (att.substr (0, 11) != "annotation_" &&
-          ! context.columns[att])
+          context.columns.find (att) == context.columns.end ())
       {
          row = view.addRow ();
          view.set (row, 0, "[" + att);
@@ -521,33 +524,32 @@ int CmdInfo::execute (std::string& output)
     if (context.config.getBoolean ("journal.info") &&
         undo.size () > 3)
     {
-      // Scan the undo data for entries matching this task.
-      std::string when;
-      std::string previous;
-      std::string current;
+      // Scan the undo data for entries matching this task, without making
+      // copies.
       unsigned int i = 0;
       long last_timestamp = 0;
       while (i < undo.size ())
       {
-        when = undo[i++];
-        previous = "";
-        if (undo[i].substr (0, 3) == "old")
-          previous = undo[i++];
+        int when = i++;
+        int previous = -1;
 
-        current = undo[i++];
+        if (! undo[i].compare (0, 3, "old", 3))
+          previous = i++;
+
+        int current = i++;
         i++; // Separator
 
-        if (current.find ("uuid:\"" + uuid) != std::string::npos)
+        if (undo[current].find ("uuid:\"" + uuid) != std::string::npos)
         {
-          if (previous != "")
+          if (previous != -1)
           {
             int row = journal.addRow ();
 
-            ISO8601d timestamp (strtol (when.substr (5).c_str (), NULL, 10));
+            ISO8601d timestamp (strtol (undo[when].substr (5).c_str (), NULL, 10));
             journal.set (row, 0, timestamp.toString (dateformat));
 
-            Task before (previous.substr (4));
-            Task after (current.substr (4));
+            Task before (undo[previous].substr (4));
+            Task after (undo[current].substr (4));
             journal.set (row, 1, taskInfoDifferences (before, after, dateformat, last_timestamp, timestamp.toEpoch()));
           }
         }
