@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdPrepend.h>
 #include <iostream>
 #include <Context.h>
 #include <Filter.h>
@@ -32,7 +33,6 @@
 #include <text.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdPrepend.h>
 
 extern Context context;
 
@@ -79,7 +79,7 @@ int CmdPrepend::execute (std::string&)
 
     // Prepend to the specified task.
     std::string question = format (STRING_CMD_PREPEND_CONFIRM,
-                                   task.id,
+                                   task.identifier (true),
                                    task.get ("description"));
 
     task.modify (Task::modPrepend, true);
