@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,13 +25,13 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdStop.h>
 #include <iostream>
 #include <Context.h>
 #include <Filter.h>
 #include <main.h>
 #include <text.h>
 #include <i18n.h>
-#include <CmdStop.h>
 
 extern Context context;
 
@@ -78,7 +78,7 @@ int CmdStop::execute (std::string&)
 
       // Stop the specified task.
       std::string question = format (STRING_CMD_STOP_CONFIRM,
-                                     task.id,
+                                     task.identifier (true),
                                      task.get ("description"));
 
       task.modify (Task::modAnnotate);
@@ -108,7 +108,7 @@ int CmdStop::execute (std::string&)
     else
     {
       std::cout << format (STRING_CMD_STOP_ALREADY,
-                           task.id,
+                           task.identifier (true),
                            task.get ("description"))
                 << "\n";
       rc = 1;
