@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdSummary.h>
 #include <algorithm>
 #include <sstream>
 #include <stdlib.h>
@@ -36,7 +37,6 @@
 #include <util.h>
 #include <i18n.h>
 #include <main.h>
-#include <CmdSummary.h>
 
 extern Context context;
 
@@ -139,11 +139,16 @@ int CmdSummary::execute (std::string& output)
   view.add (Column::factory ("string.right",      STRING_CMD_SUMMARY_COMPLETE));
   view.add (Column::factory ("string.left_fixed", "0%                        100%"));
 
-  Color bar_color (context.config.get ("color.summary.bar"));
-  Color bg_color  (context.config.get ("color.summary.background"));
-  Color label     (context.config.get ("color.label"));
+  Color bar_color;
+  Color bg_color;
+  if (context.color ())
+  {
+    bar_color = Color (context.config.get ("color.summary.bar"));
+    bg_color  = Color (context.config.get ("color.summary.background"));
 
-  view.colorHeader (label);
+    Color label (context.config.get ("color.label"));
+    view.colorHeader (label);
+  }
 
   int barWidth = 30;
   std::vector <std::string> processed;
@@ -207,14 +212,10 @@ int CmdSummary::execute (std::string& output)
         << view.render ()
         << optionalBlankLine ();
 
-    if (view.rows ())
-      out << format (STRING_CMD_PROJECTS_SUMMARY2, view.rows ());
-    else
-      out << STRING_CMD_PROJECTS_SUMMARY;
-
-    out << "\n";
+    out << format (STRING_CMD_PROJECTS_SUMMARY2, view.rows ()) << "\n";
   }
-  else {
+  else
+  {
     out << STRING_CMD_PROJECTS_NO << "\n";
     rc = 1;
   }
