@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdTimesheet.h>
 #include <sstream>
 #include <stdlib.h>
 #include <Context.h>
@@ -34,7 +35,6 @@
 #include <main.h>
 #include <i18n.h>
 #include <text.h>
-#include <CmdTimesheet.h>
 
 extern Context context;
 
@@ -93,9 +93,12 @@ int CmdTimesheet::execute (std::string& output)
                         + " - "
                         + endString.toString (context.config.get ("dateformat"));
 
-    Color bold (Color::nocolor, Color::nocolor, false, true, false);
+    Color bold;
+    if (context.color ())
+      bold = Color ("bold");
+
     out << "\n"
-        << (context.color () ? bold.colorize (title) : title)
+        << bold.colorize (title)
         << "\n";
 
     // Render the completed table.
@@ -106,8 +109,12 @@ int CmdTimesheet::execute (std::string& output)
     completed.add (Column::factory ("string.right", STRING_COLUMN_LABEL_DUE));
     completed.add (Column::factory ("string",       STRING_COLUMN_LABEL_DESC));
 
-    Color label (context.config.get ("color.label"));
-    completed.colorHeader (label);
+    Color label;
+    if (context.color ())
+    {
+      label = Color (context.config.get ("color.label"));
+      completed.colorHeader (label);
+    }
 
     for (auto& task : all)
     {
@@ -118,8 +125,7 @@ int CmdTimesheet::execute (std::string& output)
         if (compDate >= start && compDate < end)
         {
           Color c;
-          if (context.color ())
-            autoColorize (task, c);
+          autoColorize (task, c);
 
           int row = completed.addRow ();
           std::string format = context.config.get ("dateformat.report");
@@ -175,8 +181,7 @@ int CmdTimesheet::execute (std::string& output)
         if (startDate >= start && startDate < end)
         {
           Color c;
-          if (context.color ())
-            autoColorize (task, c);
+          autoColorize (task, c);
 
           int row = started.addRow ();
           std::string format = context.config.get ("dateformat.report");
