@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdUDAs.h>
 #include <sstream>
 #include <algorithm>
 #include <Context.h>
@@ -34,7 +35,6 @@
 #include <text.h>
 #include <util.h>
 #include <i18n.h>
-#include <CmdUDAs.h>
 
 extern Context context;
 
@@ -92,8 +92,11 @@ int CmdUDAs::execute (std::string& output)
     view.add (Column::factory ("string", STRING_COLUMN_LABEL_DEFAULT));
     view.add (Column::factory ("string", STRING_COLUMN_LABEL_UDACOUNT));
 
-    Color label (context.config.get ("color.label"));
-    view.colorHeader (label);
+    if (context.color ())
+    {
+      Color label (context.config.get ("color.label"));
+      view.colorHeader (label);
+    }
 
     for (auto& uda : udas)
     {
@@ -137,7 +140,7 @@ int CmdUDAs::execute (std::string& output)
   std::map <std::string, int> orphans;
   for (auto& i : filtered)
   {
-    for (auto& att : i)
+    for (auto& att : i.data)
       if (att.first.substr (0, 11) != "annotation_" &&
           context.columns.find (att.first) == context.columns.end ())
         orphans[att.first]++;
@@ -151,8 +154,11 @@ int CmdUDAs::execute (std::string& output)
     orphanView.add (Column::factory ("string", STRING_COLUMN_LABEL_ORPHAN));
     orphanView.add (Column::factory ("string", STRING_COLUMN_LABEL_UDACOUNT));
 
-    Color label (context.config.get ("color.label"));
-    orphanView.colorHeader (label);
+    if (context.color ())
+    {
+      Color label (context.config.get ("color.label"));
+      orphanView.colorHeader (label);
+    }
 
     for (auto& o : orphans)
     {
