@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,14 +25,15 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdUrgency.h>
 #include <sstream>
 #include <stdlib.h>
 #include <Context.h>
 #include <Filter.h>
+#include <Lexer.h>
 #include <main.h>
 #include <text.h>
 #include <i18n.h>
-#include <CmdUrgency.h>
 
 extern Context context;
 
@@ -45,7 +46,7 @@ CmdUrgency::CmdUrgency ()
   _read_only             = true;
   _displays_id           = false;
   _needs_gc              = true;
-  _uses_context          = true;
+  _uses_context          = false;
   _accepts_filter        = true;
   _accepts_modifications = false;
   _accepts_miscellaneous = false;
@@ -70,19 +71,10 @@ int CmdUrgency::execute (std::string& output)
   std::stringstream out;
   for (auto& task : filtered)
   {
-    if (task.id)
-    {
-      out << format (STRING_CMD_URGENCY_RESULT,
-                     task.id, trim (format (task.urgency (), 6, 3)))
-          << "\n";
-    }
-    else
-    {
-      out << format (STRING_CMD_URGENCY_RESULT,
-                     task.get ("uuid"),
-                     trim (format (task.urgency (), 6, 3)))
-          << "\n";
-    }
+    out << format (STRING_CMD_URGENCY_RESULT,
+                   task.identifier (),
+                   Lexer::trim (format (task.urgency (), 6, 3)))
+        << "\n";
   }
 
   output = out.str ();
