@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+#include <CmdVersion.h>
 #include <sstream>
 #include <stdlib.h>
 #include <Context.h>
@@ -32,7 +33,6 @@
 #ifdef HAVE_COMMIT
 #include <commit.h>
 #endif
-#include <CmdVersion.h>
 #include <text.h>
 #include <i18n.h>
 
@@ -72,12 +72,12 @@ int CmdVersion::execute (std::string& output)
   link.add (Column::factory ("string", ""));
   link.set (link.addRow (), 0, STRING_CMD_VERSION_DOCS);
 
-  Color bold ("bold");
+  Color bold;
+  if (context.color ())
+    bold = Color ("bold");
 
   out << "\n"
-      << format (STRING_CMD_VERSION_BUILT,
-                 (context.color () ? bold.colorize (PACKAGE) : PACKAGE),
-                 (context.color () ? bold.colorize (VERSION) : VERSION))
+      << format (STRING_CMD_VERSION_BUILT, bold.colorize (PACKAGE), bold.colorize (VERSION))
 
 #if defined (DARWIN)
       << "darwin"
