@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -34,6 +34,7 @@
 #include <inttypes.h>
 #include <Context.h>
 #include <ISO8601.h>
+#include <Lexer.h>
 #include <main.h>
 #include <text.h>
 #include <util.h>
@@ -49,11 +50,11 @@ std::string taskDifferences (const Task& before, const Task& after)
   // Attributes are all there is, so figure the different attribute names
   // between before and after.
   std::vector <std::string> beforeAtts;
-  for (auto& att : before)
+  for (auto& att : before.data)
     beforeAtts.push_back (att.first);
 
   std::vector <std::string> afterAtts;
-  for (auto& att : after)
+  for (auto& att : after.data)
     afterAtts.push_back (att.first);
 
   std::vector <std::string> beforeOnly;
@@ -64,7 +65,7 @@ std::string taskDifferences (const Task& before, const Task& after)
   std::stringstream out;
   for (auto& name : beforeOnly)
     out << "  - "
-        << format (STRING_FEEDBACK_DELETED, ucFirst (name))
+        << format (STRING_FEEDBACK_DELETED, Lexer::ucFirst (name))
         << "\n";
 
   for (auto& name : afterOnly)
@@ -83,7 +84,7 @@ std::string taskDifferences (const Task& before, const Task& after)
     else
       out << "  - "
           << format (STRING_FEEDBACK_ATT_SET,
-                     ucFirst (name),
+                     Lexer::ucFirst (name),
                      renderAttribute (name, after.get (name)))
           << "\n";
   }
@@ -116,7 +117,7 @@ std::string taskDifferences (const Task& before, const Task& after)
       else
         out << "  - "
             << format (STRING_FEEDBACK_ATT_MOD,
-                       ucFirst (name),
+                       Lexer::ucFirst (name),
                        renderAttribute (name, before.get (name)),
                        renderAttribute (name, after.get (name)))
             << "\n";
@@ -143,11 +144,11 @@ std::string taskInfoDifferences (
   // Attributes are all there is, so figure the different attribute names
   // between before and after.
   std::vector <std::string> beforeAtts;
-  for (auto& att : before)
+  for (auto& att : before.data)
     beforeAtts.push_back (att.first);
 
   std::vector <std::string> afterAtts;
-  for (auto& att : after)
+  for (auto& att : after.data)
     afterAtts.push_back (att.first);
 
   std::vector <std::string> beforeOnly;
@@ -175,13 +176,13 @@ std::string taskInfoDifferences (
     }
     else if (name == "start")
     {
-      out << format (STRING_FEEDBACK_ATT_DEL_DUR, ucFirst (name),
+      out << format (STRING_FEEDBACK_ATT_DEL_DUR, Lexer::ucFirst (name),
                      ISO8601p (current_timestamp - last_timestamp).format ())
           << "\n";
     }
     else
     {
-      out << format (STRING_FEEDBACK_ATT_DEL, ucFirst (name))
+      out << format (STRING_FEEDBACK_ATT_DEL, Lexer::ucFirst (name))
           << "\n";
     }
   }
@@ -209,7 +210,7 @@ std::string taskInfoDifferences (
           last_timestamp = current_timestamp;
 
       out << format (STRING_FEEDBACK_ATT_WAS_SET,
-                     ucFirst (name),
+                     Lexer::ucFirst (name),
                      renderAttribute (name, after.get (name), dateformat))
           << "\n";
     }
@@ -244,7 +245,7 @@ std::string taskInfoDifferences (
       }
       else
         out << format (STRING_FEEDBACK_ATT_WAS_MOD,
-                       ucFirst (name),
+                       Lexer::ucFirst (name),
                        renderAttribute (name, before.get (name), dateformat),
                        renderAttribute (name, after.get (name), dateformat))
             << "\n";
@@ -261,16 +262,19 @@ std::string taskInfoDifferences (
 ////////////////////////////////////////////////////////////////////////////////
 std::string renderAttribute (const std::string& name, const std::string& value, const std::string& format /* = "" */)
 {
-  Column* col = context.columns[name];
-  if (col                    &&
-      col->type () == "date" &&
-      value != "")
+  if (context.columns.find (name) != context.columns.end ())
   {
-    ISO8601d d ((time_t)strtol (value.c_str (), NULL, 10));
-    if (format == "")
-      return d.toString (context.config.get ("dateformat"));
+    Column* col = context.columns[name];
+    if (col                    &&
+        col->type () == "date" &&
+        value != "")
+    {
+      ISO8601d d ((time_t)strtol (value.c_str (), NULL, 10));
+      if (format == "")
+        return d.toString (context.config.get ("dateformat"));
 
-    return d.toString (format);
+      return d.toString (format);
+    }
   }
 
   return value;
@@ -309,12 +313,10 @@ void feedback_affected (const std::string& effect, const Task& task)
 {
   if (context.verbose ("affected"))
   {
-    if (task.id)
-      std::cout << format (effect, task.id, task.get ("description"))
-                << "\n";
-    else
-      std::cout << format (effect, task.get ("uuid"), task.get ("description"))
-                << "\n";
+    std::cout << format (effect,
+                         task.identifier (true),
+                         task.get ("description"))
+              << "\n";
   }
 }
 
@@ -373,12 +375,8 @@ void feedback_special_tags (const Task& task, const std::string& tag)
 
     if (msg.length ())
     {
-      if (task.id)
-        std::cout << format (msg, task.id)
-                  << "\n";
-      else
-        std::cout << format (msg, task.get ("uuid"))
-                  << "\n";
+      std::cout << format (msg, task.identifier ())
+                << "\n";
     }
   }
 }
@@ -506,7 +504,9 @@ std::string onExpiration (Task& task)
   std::stringstream msg;
 
   if (context.verbose ("affected"))
-    msg << format (STRING_FEEDBACK_EXPIRED, task.id, task.get ("description"));
+    msg << format (STRING_FEEDBACK_EXPIRED,
+                   task.identifier (true),
+                   task.get ("description"));
 
   return msg.str ();
 }
