@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -224,6 +224,8 @@
 #define STRING_COLUMN_LABEL_SCHED    "Geplant"
 #define STRING_COLUMN_LABEL_UDA      "Name"
 #define STRING_COLUMN_LABEL_TYPE     "Typ"
+#define STRING_COLUMN_LABEL_MODIFY   "Modifiable"
+#define STRING_COLUMN_LABEL_NOMODIFY "Read Only"
 #define STRING_COLUMN_LABEL_LABEL    "Beschreibung"
 #define STRING_COLUMN_LABEL_DEFAULT  "Standard"
 #define STRING_COLUMN_LABEL_VALUES   "Erlaubte Werte"
@@ -260,7 +262,7 @@
 #define STRING_CMD_VERSION_DOCS      "Dokumentation für taskwarrior finden Sie in 'man task', 'man taskrc', 'man task-color', 'man task-sync' oder auf http://taskwarrior.org"
 #define STRING_CMD_VERSION_BUILT     "{1} {2}, gebaut für "
 #define STRING_CMD_VERSION_UNKNOWN   "unbekannt"
-#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2015 P. Beckingham, F. Hernandez."
+#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2016 P. Beckingham, F. Hernandez."
 #define STRING_CMD_LOGO_USAGE        "Zeigt das taskwarrior-Logo"
 #define STRING_CMD_LOGO_COLOR_REQ    "Der Logo-Befehle benötigt aktivierte Farbunterstützung"
 #define STRING_CMD_EXEC_USAGE        "Führt externe Befehle und Skripte aus"
@@ -268,6 +270,7 @@
 #define STRING_CMD_URGENCY_RESULT    "Aufgabe {1}, Dringlichkeit {2}"
 #define STRING_CMD_ADD_USAGE         "Fügt eine neue Aufgabe hinzu"
 #define STRING_CMD_ADD_FEEDBACK      "Aufgabe {1} hinzugefügt."
+#define STRING_CMD_ADD_RECUR         "Created task {1} (recurrence template)."
 #define STRING_CMD_LOG_USAGE         "Protokolliert eine Aufgabe"
 #define STRING_CMD_LOG_NO_RECUR      "Wiederholende Aufgaben können nicht protokolliert werden."
 #define STRING_CMD_LOG_NO_WAITING    "Aufgeschobene Aufgaben können nicht protokolliert werden."
@@ -500,11 +503,15 @@
 #define STRING_CMD_DIAG_COMMIT       "Commit"
 #define STRING_CMD_DIAG_FOUND        "(found)"
 #define STRING_CMD_DIAG_MISSING      "(missing)"
+#define STRING_CMD_DIAG_MISS_DEP     "Task {1} depends on nonexistent task: {2}"
+#define STRING_CMD_DIAG_MISS_PAR     "Task {1} has nonexistent recurrence template: {2}"
 #define STRING_CMD_DIAG_ENABLED      "Enabled"
 #define STRING_CMD_DIAG_DISABLED     "Disabled"
 #define STRING_CMD_DIAG_CONFIG       "Configuration"
 #define STRING_CMD_DIAG_TESTS        "Tests"
 #define STRING_CMD_DIAG_UUID_SCAN    "Scanned {1} tasks for duplicate UUIDs:"
+#define STRING_CMD_DIAG_REF_SCAN     "Scanned {1} tasks for broken references:"
+#define STRING_CMD_DIAG_REF_OK       "No broken references found"
 #define STRING_CMD_DIAG_UUID_DUP     "Found duplicate {1}"
 #define STRING_CMD_DIAG_UUID_NO_DUP  "No duplicates found"
 #define STRING_CMD_DIAG_NONE         "-none-"
@@ -534,6 +541,7 @@
 #define STRING_CMD_MODIFY_CONFIRM    "Aufgabe {1} '{2}' ändern?"
 #define STRING_CMD_MODIFY_RECUR      "Dies ist eine wiederholende Aufgabe.  Möchten Sie alle offenen Wiederholungen dieser Aufgabe ändern?"
 #define STRING_CMD_MODIFY_NEED_TEXT  "Weiterer Text muss angegeben werden."
+#define STRING_CMD_MODIFY_INACTIVE   "Note: Modified task {1} is {2}.  You may wish to make this task pending with: task {3} modify status:pending"
 
 #define STRING_CMD_COLOR_USAGE       "Alle Farben, ein Beispiel, oder eine Legende"
 #define STRING_CMD_COLOR_HERE        "Diese Farben werden zur Zeit genutzt:"
