@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -224,6 +224,8 @@
 #define STRING_COLUMN_LABEL_SCHED    "Fissato"
 #define STRING_COLUMN_LABEL_UDA      "Nome"
 #define STRING_COLUMN_LABEL_TYPE     "Tipo"
+#define STRING_COLUMN_LABEL_MODIFY   "Modifiable"
+#define STRING_COLUMN_LABEL_NOMODIFY "Read Only"
 #define STRING_COLUMN_LABEL_LABEL    "Etichetta"
 #define STRING_COLUMN_LABEL_DEFAULT  "Predefinito"
 #define STRING_COLUMN_LABEL_VALUES   "Valori consentiti"
@@ -259,7 +261,7 @@
 #define STRING_CMD_VERSION_DOCS      "La documentazione di taskwarrior è consultabile con 'man task', 'man taskrc', 'man task-color', 'man task-sync' o presso http://taskwarrior.org"
 #define STRING_CMD_VERSION_BUILT     "{1} {2} generato per "
 #define STRING_CMD_VERSION_UNKNOWN   "sconosciuto"
-#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2015 P. Beckingham, F. Hernandez."
+#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2016 P. Beckingham, F. Hernandez."
 #define STRING_CMD_LOGO_USAGE        "Mostra il logo di Taskwarrior"
 #define STRING_CMD_LOGO_COLOR_REQ    "Il comando logo richiede l'abilitazione del supporto ai colori."
 #define STRING_CMD_EXEC_USAGE        "Esegue comandi e script esterni"
@@ -267,6 +269,7 @@
 #define STRING_CMD_URGENCY_RESULT    "task {1} urgenza {2}"
 #define STRING_CMD_ADD_USAGE         "Aggiunge un nuovo task"
 #define STRING_CMD_ADD_FEEDBACK      "Task {1} creato."
+#define STRING_CMD_ADD_RECUR         "Created task {1} (recurrence template)."
 #define STRING_CMD_LOG_USAGE         "Aggiunge un nuovo task già completato"
 #define STRING_CMD_LOG_NO_RECUR      "Task periodici non possono essere registrati."
 #define STRING_CMD_LOG_NO_WAITING    "Task in attesa non possono essere registrati."
@@ -499,11 +502,15 @@
 #define STRING_CMD_DIAG_COMMIT       "Commit"
 #define STRING_CMD_DIAG_FOUND        "(trovato)"
 #define STRING_CMD_DIAG_MISSING      "(mancante)"
+#define STRING_CMD_DIAG_MISS_DEP     "Task {1} depends on nonexistent task: {2}"
+#define STRING_CMD_DIAG_MISS_PAR     "Task {1} has nonexistent recurrence template: {2}"
 #define STRING_CMD_DIAG_ENABLED      "Abilitato"
 #define STRING_CMD_DIAG_DISABLED     "Disabilitato"
 #define STRING_CMD_DIAG_CONFIG       "Configurazione"
 #define STRING_CMD_DIAG_TESTS        "Test"
 #define STRING_CMD_DIAG_UUID_SCAN    "Valutati {1} task per duplicazione UUID:"
+#define STRING_CMD_DIAG_REF_SCAN     "Scanned {1} tasks for broken references:"
+#define STRING_CMD_DIAG_REF_OK       "No broken references found"
 #define STRING_CMD_DIAG_UUID_DUP     "Trovato duplicato {1}"
 #define STRING_CMD_DIAG_UUID_NO_DUP  "Nessun duplicato trovato"
 #define STRING_CMD_DIAG_NONE         "-nessuno-"
@@ -533,6 +540,7 @@
 #define STRING_CMD_MODIFY_CONFIRM    "Modificare il task {1} '{2}'?"
 #define STRING_CMD_MODIFY_RECUR      "Questo è un task periodico. Modificare tutti i task associati?"
 #define STRING_CMD_MODIFY_NEED_TEXT  "Testo aggiunti da specificare."
+#define STRING_CMD_MODIFY_INACTIVE   "Note: Modified task {1} is {2}.  You may wish to make this task pending with: task {3} modify status:pending"
 
 #define STRING_CMD_COLOR_USAGE       "Tutti i colori, un esempio, o una legenda"
 #define STRING_CMD_COLOR_HERE        "Coloti in uso:"
