@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -224,6 +224,8 @@
 #define STRING_COLUMN_LABEL_SCHED    "Scheduled"
 #define STRING_COLUMN_LABEL_UDA      "Name"
 #define STRING_COLUMN_LABEL_TYPE     "Type"
+#define STRING_COLUMN_LABEL_MODIFY   "Modifiable"
+#define STRING_COLUMN_LABEL_NOMODIFY "Read Only"
 #define STRING_COLUMN_LABEL_LABEL    "Label"
 #define STRING_COLUMN_LABEL_DEFAULT  "Default"
 #define STRING_COLUMN_LABEL_VALUES   "Allowed Values"
@@ -260,7 +262,7 @@
 #define STRING_CMD_VERSION_DOCS      "taskwarrior のドキュメントは 'man task', 'man taskrc', 'man task-color', 'man task-sync' あるいは http://taskwarrior.org にあります。"
 #define STRING_CMD_VERSION_BUILT     "{1} {2} built for "
 #define STRING_CMD_VERSION_UNKNOWN   "unknown"
-#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2015 P. Beckingham, F. Hernandez."
+#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2016 P. Beckingham, F. Hernandez."
 #define STRING_CMD_LOGO_USAGE        "Taskwarrior ロゴの表示"
 #define STRING_CMD_LOGO_COLOR_REQ    "色のサポートをする logo コマンドが有効になりました。"
 #define STRING_CMD_EXEC_USAGE        "外部コマンドまたはスクリプトの実行"
@@ -268,6 +270,7 @@
 #define STRING_CMD_URGENCY_RESULT    "task {1} urgency {2}"
 #define STRING_CMD_ADD_USAGE         "新しいタスクの追加"
 #define STRING_CMD_ADD_FEEDBACK      "タスク {1} が生成されました。"
+#define STRING_CMD_ADD_RECUR         "Created task {1} (recurrence template)."
 #define STRING_CMD_LOG_USAGE         "Adds a new task that is already completed"
 #define STRING_CMD_LOG_NO_RECUR      "You cannot log recurring tasks."
 #define STRING_CMD_LOG_NO_WAITING    "保留のタスクはログできません。"
@@ -500,11 +503,15 @@
 #define STRING_CMD_DIAG_COMMIT       "Commit"
 #define STRING_CMD_DIAG_FOUND        "(found)"
 #define STRING_CMD_DIAG_MISSING      "(missing)"
+#define STRING_CMD_DIAG_MISS_DEP     "Task {1} depends on nonexistent task: {2}"
+#define STRING_CMD_DIAG_MISS_PAR     "Task {1} has nonexistent recurrence template: {2}"
 #define STRING_CMD_DIAG_ENABLED      "Enabled"
 #define STRING_CMD_DIAG_DISABLED     "Disabled"
 #define STRING_CMD_DIAG_CONFIG       "Configuration"
 #define STRING_CMD_DIAG_TESTS        "Tests"
 #define STRING_CMD_DIAG_UUID_SCAN    "Scanned {1} tasks for duplicate UUIDs:"
+#define STRING_CMD_DIAG_REF_SCAN     "Scanned {1} tasks for broken references:"
+#define STRING_CMD_DIAG_REF_OK       "No broken references found"
 #define STRING_CMD_DIAG_UUID_DUP     "Found duplicate {1}"
 #define STRING_CMD_DIAG_UUID_NO_DUP  "No duplicates found"
 #define STRING_CMD_DIAG_NONE         "-none-"
@@ -534,6 +541,7 @@
 #define STRING_CMD_MODIFY_CONFIRM    "タスク {1} '{2}' を変更しますか?"
 #define STRING_CMD_MODIFY_RECUR      "This is a recurring task.  Do you want to modify all pending recurrences of this same task?"
 #define STRING_CMD_MODIFY_NEED_TEXT  "Additional text must be provided."
+#define STRING_CMD_MODIFY_INACTIVE   "Note: Modified task {1} is {2}.  You may wish to make this task pending with: task {3} modify status:pending"
 
 #define STRING_CMD_COLOR_USAGE       "All colors, a sample, or a legend"
 #define STRING_CMD_COLOR_HERE        "Here are the colors currently in use:"
@@ -841,7 +849,7 @@
 #define STRING_TASK_NO_FF1           "Taskwarrior no longer supports file format 1, originally used between 27 November 2006 and 31 December 2007."
 #define STRING_TASK_NO_FF2           "Taskwarrior no longer supports file format 2, originally used between 1 January 2008 and 12 April 2009."
 #define STRING_TASK_NO_FF3           "Taskwarrior no longer supports file format 3, originally used between 23 March 2009 and 16 May 2009."
-#define STRING_TASK_PARSE_UNREC_FF   "Unrecognized taskwarrior file format."
+#define STRING_TASK_PARSE_UNREC_FF   "Unrecognized Taskwarrior file format or blank line in data."
 #define STRING_TASK_DEPEND_ITSELF    "A task cannot be dependent on itself."
 #define STRING_TASK_DEPEND_MISS_CREA "Could not create a dependency on task {1} - not found."
 #define STRING_TASK_DEPEND_MISS_DEL  "Could not delete a dependency on task {1} - not found."
