@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -224,6 +224,8 @@
 #define STRING_COLUMN_LABEL_SCHED    "Zaplanowane"
 #define STRING_COLUMN_LABEL_UDA      "Nazwa"
 #define STRING_COLUMN_LABEL_TYPE     "Typ"
+#define STRING_COLUMN_LABEL_MODIFY   "Modifiable"
+#define STRING_COLUMN_LABEL_NOMODIFY "Read Only"
 #define STRING_COLUMN_LABEL_LABEL    "Etykieta"
 #define STRING_COLUMN_LABEL_DEFAULT  "Domyślne"
 #define STRING_COLUMN_LABEL_VALUES   "Dozwolone Wartości"
@@ -260,7 +262,7 @@
 #define STRING_CMD_VERSION_DOCS      "Dokumentację dla taskwarrior można znaleźć z pomocą 'man task', 'man taskrc', 'man task-tutorial', 'man task-color', 'man task-sync', 'man task-faq' lub pod adresem http://taskwarrior.org"
 #define STRING_CMD_VERSION_BUILT     "{1} {2} zbudowane dla "
 #define STRING_CMD_VERSION_UNKNOWN   "nieznana"
-#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2015 P. Beckingham, F. Hernandez."
+#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2016 P. Beckingham, F. Hernandez."
 #define STRING_CMD_LOGO_USAGE        "Wyświetla logo Taskwarrior"
 #define STRING_CMD_LOGO_COLOR_REQ    "Polecenie logo wymaga wsparcia kolorowania."
 #define STRING_CMD_EXEC_USAGE        "Wykonuje zewnętrzne polecenia i skrypty"
@@ -268,6 +270,7 @@
 #define STRING_CMD_URGENCY_RESULT    "zadanie {1} ważność {2}"
 #define STRING_CMD_ADD_USAGE         "Dodaje nowe zadanie"
 #define STRING_CMD_ADD_FEEDBACK      "Utworzono zadanie {1}."
+#define STRING_CMD_ADD_RECUR         "Created task {1} (recurrence template)."
 #define STRING_CMD_LOG_USAGE         "Dodaje nowe, ukończone zadanie"
 #define STRING_CMD_LOG_NO_RECUR      "Nie możesz logować zadania cyklicznego."
 #define STRING_CMD_LOG_NO_WAITING    "Nie możesz logować zadania czekającego."
@@ -500,11 +503,15 @@
 #define STRING_CMD_DIAG_COMMIT       "Zatwierdzenie"
 #define STRING_CMD_DIAG_FOUND        "(jest)"
 #define STRING_CMD_DIAG_MISSING      "(brak)"
+#define STRING_CMD_DIAG_MISS_DEP     "Task {1} depends on nonexistent task: {2}"
+#define STRING_CMD_DIAG_MISS_PAR     "Task {1} has nonexistent recurrence template: {2}"
 #define STRING_CMD_DIAG_ENABLED      "Włączone"
 #define STRING_CMD_DIAG_DISABLED     "Wyłączone"
 #define STRING_CMD_DIAG_CONFIG       "Konfiguracja"
 #define STRING_CMD_DIAG_TESTS        "Testy"
 #define STRING_CMD_DIAG_UUID_SCAN    "Zeskanowano {1} zadań w poszukiwaniu zdublowanych UUIDów:"
+#define STRING_CMD_DIAG_REF_SCAN     "Scanned {1} tasks for broken references:"
+#define STRING_CMD_DIAG_REF_OK       "No broken references found"
 #define STRING_CMD_DIAG_UUID_DUP     "Znaleziono duplikaty {1}"
 #define STRING_CMD_DIAG_UUID_NO_DUP  "Nie znaleziono duplikatów"
 #define STRING_CMD_DIAG_NONE         "-brak-"
@@ -534,6 +541,7 @@
 #define STRING_CMD_MODIFY_CONFIRM    "Zmienić zadanie {1} '{2}'?"
 #define STRING_CMD_MODIFY_RECUR      "To zadanie jest cykliczne. Czy chcesz zmodyfikować kolejne zadania w cyklu?"
 #define STRING_CMD_MODIFY_NEED_TEXT  "Należy podać tekst"
+#define STRING_CMD_MODIFY_INACTIVE   "Note: Modified task {1} is {2}.  You may wish to make this task pending with: task {3} modify status:pending"
 
 #define STRING_CMD_COLOR_USAGE       "Wszystkie kolory, próbki lub legenda"
 #define STRING_CMD_COLOR_HERE        "To są aktualnie używane kolory:"
