@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -225,6 +225,8 @@
 #define STRING_COLUMN_LABEL_SCHED    "Agendado"
 #define STRING_COLUMN_LABEL_UDA      "Nome"
 #define STRING_COLUMN_LABEL_TYPE     "Tipo"
+#define STRING_COLUMN_LABEL_MODIFY   "Modifiable"
+#define STRING_COLUMN_LABEL_NOMODIFY "Read Only"
 #define STRING_COLUMN_LABEL_LABEL    "Rótulo"
 #define STRING_COLUMN_LABEL_DEFAULT  "Por omissão"
 #define STRING_COLUMN_LABEL_VALUES   "Valores Permitidos"
@@ -260,7 +262,7 @@
 #define STRING_CMD_VERSION_DOCS      "A documentação do taskwarrior pode ser encontrada usando os comandos 'man task', 'man taskrc', 'man task-color', 'man task-sync' ou em http://taskwarrior.org"
 #define STRING_CMD_VERSION_BUILT     "{1} {2} construido para "
 #define STRING_CMD_VERSION_UNKNOWN   "desconhecido"
-#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2015 P. Beckingham, F. Hernandez."  // |por-PRT|==|eng-USA|
+#define STRING_CMD_VERSION_COPY      "Copyright (C) 2006 - 2016 P. Beckingham, F. Hernandez."  // |por-PRT|==|eng-USA|
 #define STRING_CMD_LOGO_USAGE        "Exibe o logotipo do Taskwarrior"
 #define STRING_CMD_LOGO_COLOR_REQ    "O comando logo requer que o suporte de cor seja ativado."
 #define STRING_CMD_EXEC_USAGE        "Executa comandos e scripts externos"
@@ -268,6 +270,7 @@
 #define STRING_CMD_URGENCY_RESULT    "Tarefa {1} urgência {2}"
 #define STRING_CMD_ADD_USAGE         "Adiciona uma nova tarefa"
 #define STRING_CMD_ADD_FEEDBACK      "Criada a tarefa {1}."
+#define STRING_CMD_ADD_RECUR         "Created task {1} (recurrence template)."
 #define STRING_CMD_LOG_USAGE         "Adiciona uma nova tarefa que já está concluída"
 #define STRING_CMD_LOG_NO_RECUR      "Não pode usar o comando 'log' para tarefas recorrentes."
 #define STRING_CMD_LOG_NO_WAITING    "Não pode usar o comando 'log' para tarefas adiadas."
@@ -500,11 +503,15 @@
 #define STRING_CMD_DIAG_COMMIT       "Commit"  // |por-PRT|==|eng-USA|
 #define STRING_CMD_DIAG_FOUND        "(presente)"
 #define STRING_CMD_DIAG_MISSING      "(em falta)"
+#define STRING_CMD_DIAG_MISS_DEP     "Task {1} depends on nonexistent task: {2}"
+#define STRING_CMD_DIAG_MISS_PAR     "Task {1} has nonexistent recurrence template: {2}"
 #define STRING_CMD_DIAG_ENABLED      "Ativado"
 #define STRING_CMD_DIAG_DISABLED     "Desativado"
 #define STRING_CMD_DIAG_CONFIG       "Configuração"
 #define STRING_CMD_DIAG_TESTS        "Testes"
 #define STRING_CMD_DIAG_UUID_SCAN    "UUIDs duplicados em {1} tarefas:"
+#define STRING_CMD_DIAG_REF_SCAN     "Scanned {1} tasks for broken references:"
+#define STRING_CMD_DIAG_REF_OK       "No broken references found"
 #define STRING_CMD_DIAG_UUID_DUP     "UUID duplicado {1}"
 #define STRING_CMD_DIAG_UUID_NO_DUP  "Nenhum duplicado encontrado"
 #define STRING_CMD_DIAG_NONE         "-nenhum-"
@@ -534,6 +541,7 @@
 #define STRING_CMD_MODIFY_CONFIRM    "Modificar tarefa {1} '{2}'?"
 #define STRING_CMD_MODIFY_RECUR      "Esta é uma tarefa recorrente. Deseja modificar todas as recorrências pendentes da mesma?"
 #define STRING_CMD_MODIFY_NEED_TEXT  "É necessário fornecer mais informação."
+#define STRING_CMD_MODIFY_INACTIVE   "Note: Modified task {1} is {2}.  You may wish to make this task pending with: task {3} modify status:pending"
 
 #define STRING_CMD_COLOR_USAGE       "Todas as cores, uma amostra ou a legenda"
 #define STRING_CMD_COLOR_HERE        "Estas são as cores actualmente em uso:"
