@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,6 +27,7 @@
 #ifndef INCLUDED_MAIN
 #define INCLUDED_MAIN
 
+#include <algorithm>
 #include <string>
 #include <vector>
 #include <map>
@@ -83,75 +84,19 @@ std::string legacyCheckForDeprecatedColumns ();
 void legacyAttributeMap (std::string&);
 
 // list template
-///////////////////////////////////////////////////////////////////////////////
-template <class T> bool listDiff (const T& left, const T& right)
-{
-  if (left.size () != right.size ())
-    return true;
-
-  for (unsigned int i = 0; i < left.size (); ++i)
-    if (left[i] != right[i])
-      return true;
-
-  return false;
-}
-
 ///////////////////////////////////////////////////////////////////////////////
 template <class T> void listDiff (
   const T& left, const T& right, T& leftOnly, T& rightOnly)
 {
   leftOnly.clear ();
+  for (auto& l : left)
+    if (std::find (right.begin (), right.end (), l) == right.end ())
+      leftOnly.push_back (l);
+
   rightOnly.clear ();
-
-  for (unsigned int l = 0; l < left.size (); ++l)
-  {
-    bool found = false;
-    for (unsigned int r = 0; r < right.size (); ++r)
-    {
-      if (left[l] == right[r])
-      {
-        found = true;
-        break;
-      }
-    }
-
-    if (!found)
-      leftOnly.push_back (left[l]);
-  }
-
-  for (unsigned int r = 0; r < right.size (); ++r)
-  {
-    bool found = false;
-    for (unsigned int l = 0; l < left.size (); ++l)
-    {
-      if (left[l] == right[r])
-      {
-        found = true;
-        break;
-      }
-    }
-
-    if (!found)
-      rightOnly.push_back (right[r]);
-  }
-}
-
-////////////////////////////////////////////////////////////////////////////////
-template <class T> void listIntersect (const T& left, const T& right, T& join)
-{
-  join.clear ();
-
-  for (unsigned int l = 0; l < left.size (); ++l)
-  {
-    for (unsigned int r = 0; r < right.size (); ++r)
-    {
-      if (left[l] == right[r])
-      {
-        join.push_back (left[l]);
-        break;
-      }
-    }
-  }
+  for (auto& r : right)
+    if (std::find (left.begin (), left.end (), r) == left.end ())
+      rightOnly.push_back (r);
 }
 
 #endif
