@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -153,27 +153,6 @@ void join (
   result = s.str ();
 }
 
-////////////////////////////////////////////////////////////////////////////////
-std::string trimLeft (const std::string& in, const std::string& t /*= " "*/)
-{
-  std::string out = in;
-  return out.erase (0, in.find_first_not_of (t));
-}
-
-////////////////////////////////////////////////////////////////////////////////
-std::string trimRight (const std::string& in, const std::string& t /*= " "*/)
-{
-  std::string out = in;
-  return out.erase (out.find_last_not_of (t) + 1);
-}
-
-////////////////////////////////////////////////////////////////////////////////
-std::string trim (const std::string& in, const std::string& t /*= " "*/)
-{
-  std::string out = in;
-  return trimLeft (trimRight (out, t), t);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Remove enclosing balanced quotes.  Assumes trimmed text.
 std::string unquoteText (const std::string& input)
@@ -246,22 +225,7 @@ int longestLine (const std::string& input)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// Walk the input text looking for a break point.  A break point is one of:
-//   - EOS
-//   - \n
-//   - last space before 'length' characters
-//   - last punctuation (, ; . :) before 'length' characters, even if not
-//     followed by a space
-//   - first 'length' characters
-//
-// text       "one two three\n  four"
-// bytes       0123456789012 3456789
-// characters  1234567890a23 4567890
-//
-// leading_ws
-// ws             ^   ^       ^^
-// punct
-// break                     ^
+// Break UTF8 text into chunks no more than width characters.
 bool extractLine (
   std::string& line,
   const std::string& text,
@@ -270,185 +234,82 @@ bool extractLine (
   unsigned int& offset)
 {
   // Terminate processing.
-  // Note: bytes vs bytes.
   if (offset >= text.length ())
     return false;
 
-  std::string::size_type last_last_bytes = offset;
-  std::string::size_type last_bytes = offset;
-  std::string::size_type bytes = offset;
-  unsigned int last_ws = 0;
-  int character;
-  int char_width = 0;
-  int line_width = 0;
-  while (1)
+  int line_length                     {0};
+  int character                       {0};
+  std::string::size_type lastWordEnd  {std::string::npos};
+  bool something                      {false};
+  std::string::size_type cursor       {offset};
+  std::string::size_type prior_cursor {offset};
+  while ((character = utf8_next_char (text, cursor)))
   {
-    last_last_bytes = last_bytes;
-    last_bytes = bytes;
-    character = utf8_next_char (text, bytes);
-
-    if (character == 0 ||
-        character == '\n')
+    // Premature EOL.
+    if (character == '\n')
     {
-      line = text.substr (offset, last_bytes - offset);
-      offset = bytes;
-      break;
-    }
-    else if (character == ' ')
-      last_ws = last_bytes;
-
-    char_width = mk_wcwidth (character);
-    if (line_width + char_width > width)
-    {
-      int last_last_character = text[last_last_bytes];
-      int last_character = text[last_bytes];
-
-      // [case 1] one| two --> last_last != 32, last == 32, ws == 0
-      if (last_last_character != ' ' &&
-          last_character      == ' ')
-      {
-        line = text.substr (offset, last_bytes - offset);
-        offset = last_bytes + 1;
-        break;
-      }
-
-      // [case 2] one |two --> last_last == 32, last != 32, ws != 0
-      else if (last_last_character == ' ' &&
-               last_character      != ' ' &&
-               last_ws             != 0)
-      {
-        line = text.substr (offset, last_bytes - offset - 1);
-        offset = last_bytes;
-        break;
-      }
-
-      else if (last_last_character != ' ' &&
-               last_character      != ' ')
-      {
-        // [case 3] one t|wo --> last_last != 32, last != 32, ws != 0
-        if (last_ws != 0)
-        {
-          line = text.substr (offset, last_ws - offset);
-          offset = last_ws + 1;
-          break;
-        }
-        // [case 4] on|e two --> last_last != 32, last != 32, ws == 0
-        else
-        {
-          if (hyphenate)
-          {
-            line = text.substr (offset, last_bytes - offset - 1) + "-";
-            offset = last_last_bytes;
-          }
-          else
-          {
-            line = text.substr (offset, last_bytes - offset);
-            offset = last_bytes;
-          }
-        }
-
-        break;
-      }
+      line = text.substr (offset, line_length);
+      offset = cursor;
+      return true;
     }
 
-    line_width += char_width;
-  }
-
-  return true;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-std::string commify (const std::string& data)
-{
-  // First scan for decimal point and end of digits.
-  int decimalPoint = -1;
-  int end          = -1;
-
-  int i;
-  for (int i = 0; i < (int) data.length (); ++i)
-  {
-    if (Lexer::isDigit (data[i]))
-      end = i;
-
-    if (data[i] == '.')
-      decimalPoint = i;
-  }
-
-  std::string result;
-  if (decimalPoint != -1)
-  {
-    // In reverse order, transfer all digits up to, and including the decimal
-    // point.
-    for (i = (int) data.length () - 1; i >= decimalPoint; --i)
-      result += data[i];
-
-    int consecutiveDigits = 0;
-    for (; i >= 0; --i)
+    if (! Lexer::isWhitespace (character))
     {
-      if (Lexer::isDigit (data[i]))
-      {
-        result += data[i];
+      something = true;
+      if (! text[cursor] || Lexer::isWhitespace (text[cursor]))
+        lastWordEnd = prior_cursor;
+    }
 
-        if (++consecutiveDigits == 3 && i && Lexer::isDigit (data[i - 1]))
-        {
-          result += ',';
-          consecutiveDigits = 0;
-        }
+    line_length += mk_wcwidth (character);
+
+    if (line_length >= width)
+    {
+      // Backtrack to previous word end.
+      if (lastWordEnd != std::string::npos)
+      {
+        // Eat one WS after lastWordEnd.
+        std::string::size_type lastBreak = lastWordEnd;
+        utf8_next_char (text, lastBreak);
+
+        // Position offset at following char.
+        std::string::size_type nextStart = lastBreak;
+        utf8_next_char (text, nextStart);
+
+        line = text.substr (offset, lastBreak - offset);
+        offset = nextStart;
+        return true;
       }
+
+      // No backtrack, possible hyphenation.
+      else if (hyphenate)
+      {
+        line = text.substr (offset, prior_cursor - offset) + "-";
+        offset = prior_cursor;
+        return true;
+      }
+
+      // No hyphenation, just truncation.
       else
-        result += data[i];
-    }
-  }
-  else
-  {
-    // In reverse order, transfer all digits up to, but not including the last
-    // digit.
-    for (i = (int) data.length () - 1; i > end; --i)
-      result += data[i];
-
-    int consecutiveDigits = 0;
-    for (; i >= 0; --i)
-    {
-      if (Lexer::isDigit (data[i]))
       {
-        result += data[i];
-
-        if (++consecutiveDigits == 3 && i && Lexer::isDigit (data[i - 1]))
-        {
-          result += ',';
-          consecutiveDigits = 0;
-        }
+        line = text.substr (offset, cursor - offset);
+        offset = cursor;
+        return true;
       }
-      else
-        result += data[i];
     }
+
+    // Hindsight.
+    prior_cursor = cursor;
   }
 
-  // reverse result into data.
-  std::string done;
-  for (int i = (int) result.length () - 1; i >= 0; --i)
-    done += result[i];
+  // Residual text.
+  if (something)
+  {
+    line = text.substr (offset, cursor - offset);
+     offset = cursor;
+    return true;
+  }
 
-  return done;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-std::string lowerCase (const std::string& input)
-{
-  std::string output = input;
-  std::transform (output.begin (), output.end (), output.begin (), tolower);
-  return output;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-std::string ucFirst (const std::string& input)
-{
-  std::string output = input;
-
-  if (output.length () > 0)
-    output[0] = toupper (output[0]);
-
-  return output;
+  return false;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -769,6 +630,14 @@ std::string leftJustify (const int input, const int width)
 ////////////////////////////////////////////////////////////////////////////////
 std::string leftJustify (const std::string& input, const int width)
 {
+  auto len = static_cast <int> (utf8_text_width (input));
+
+  if (len == width)
+    return input;
+
+  if (len > width)
+    return input.substr (0, width);
+
   return input + std::string (width - utf8_text_width (input), ' ');
 }
 
@@ -791,8 +660,15 @@ std::string rightJustify (const int input, const int width)
 ////////////////////////////////////////////////////////////////////////////////
 std::string rightJustify (const std::string& input, const int width)
 {
-  unsigned int len = utf8_text_width (input);
-  return (((unsigned int) width > len)
+  auto len = static_cast <int> (utf8_text_width (input));
+
+  if (len == width)
+    return input;
+
+  if (len > width)
+    return input.substr (0, width);
+
+  return ((width > len)
            ? std::string (width - len, ' ')
            : "")
          + input;
